@@ -1,5 +1,5 @@
 # /*##########################################################################
-# Copyright (C) 2016-2022 European Synchrotron Radiation Facility
+# Copyright (C) 2016-2023 European Synchrotron Radiation Facility
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -27,12 +27,12 @@ __license__ = "MIT"
 __date__ = "17/01/2019"
 
 import argparse
-import glob
 import logging
 import os
 import signal
 import sys
-from typing import Generator, Iterable
+import traceback
+from silx.app.utils import parseutils
 
 
 _logger = logging.getLogger(__name__)
@@ -42,72 +42,53 @@ _logger = logging.getLogger(__name__)
 def createParser():
     parser = argparse.ArgumentParser(description=__doc__)
     parser.add_argument(
-        'files',
+        "files",
         nargs=argparse.ZERO_OR_MORE,
-        help='Data file to show (h5 file, edf files, spec files)')
+        help="Data file to show (h5 file, edf files, spec files)",
+    )
     parser.add_argument(
-        '--debug',
+        "--slices",
+        dest="slices",
+        default=tuple(),
+        type=int,
+        nargs="+",
+        help="List of slice indices to open (Only for dataset)",
+    )
+    parser.add_argument(
+        "--debug",
         dest="debug",
         action="store_true",
         default=False,
-        help='Set logging system in debug mode')
+        help="Set logging system in debug mode",
+    )
     parser.add_argument(
-        '--use-opengl-plot',
+        "--use-opengl-plot",
         dest="use_opengl_plot",
         action="store_true",
         default=False,
-        help='Use OpenGL for plots (instead of matplotlib)')
+        help="Use OpenGL for plots (instead of matplotlib)",
+    )
     parser.add_argument(
-        '-f', '--fresh',
+        "-f",
+        "--fresh",
         dest="fresh_preferences",
         action="store_true",
         default=False,
-        help='Start the application using new fresh user preferences')
+        help="Start the application using new fresh user preferences",
+    )
     parser.add_argument(
-        '--hdf5-file-locking',
+        "--hdf5-file-locking",
         dest="hdf5_file_locking",
         action="store_true",
         default=False,
-        help='Start the application with HDF5 file locking enabled (it is disabled by default)')
+        help="Start the application with HDF5 file locking enabled (it is disabled by default)",
+    )
     return parser
 
 
-def filesArgToUrls(filenames: Iterable[str]) -> Generator[object, None, None]:
-    """Expand filenames and HDF5 data path in files input argument"""
-    # Imports here so they are performed after setting HDF5_USE_FILE_LOCKING and logging level
-    import silx.io
-    from silx.io.utils import match
-    from silx.io.url import DataUrl
-    import silx.utils.files
-
-    for filename in filenames:
-        url = DataUrl(filename)
-
-        for file_path in sorted(silx.utils.files.expand_filenames([url.file_path()])):
-            if url.data_path() is not None and glob.has_magic(url.data_path()):
-                try:
-                    with silx.io.open(file_path) as f:
-                        data_paths = list(match(f, url.data_path()))
-                except BaseException as e:
-                    _logger.error(
-                        f"Error searching HDF5 path pattern '{url.data_path()}' in file '{file_path}': Ignored")
-                    _logger.error(e.args[0])
-                    _logger.debug("Backtrace", exc_info=True)
-                    continue
-            else:
-                data_paths = [url.data_path()]
-
-            for data_path in data_paths:
-                yield DataUrl(
-                    file_path=file_path,
-                    data_path=data_path,
-                    data_slice=url.data_slice(),
-                    scheme=url.scheme(),
-                )
-
-
 def createWindow(parent, settings):
     from .Viewer import Viewer
+
     window = Viewer(parent=None, settings=settings)
     return window
 
@@ -127,7 +108,7 @@ def mainQt(options):
     except ImportError:
         _logger.debug("No resource module available")
     else:
-        if hasattr(resource, 'RLIMIT_NOFILE'):
+        if hasattr(resource, "RLIMIT_NOFILE"):
             try:
                 hard_nofile = resource.getrlimit(resource.RLIMIT_NOFILE)[1]
                 resource.setrlimit(resource.RLIMIT_NOFILE, (hard_nofile, hard_nofile))
@@ -137,9 +118,9 @@ def mainQt(options):
                 _logger.debug("Set max opened files to %d", hard_nofile)
 
     # This needs to be done prior to load HDF5
-    hdf5_file_locking = 'TRUE' if options.hdf5_file_locking else 'FALSE'
-    _logger.info('Set HDF5_USE_FILE_LOCKING=%s', hdf5_file_locking)
-    os.environ['HDF5_USE_FILE_LOCKING'] = hdf5_file_locking
+    hdf5_file_locking = "TRUE" if options.hdf5_file_locking else "FALSE"
+    _logger.info("Set HDF5_USE_FILE_LOCKING=%s", hdf5_file_locking)
+    os.environ["HDF5_USE_FILE_LOCKING"] = hdf5_file_locking
 
     try:
         # it should be loaded before h5py
@@ -151,6 +132,7 @@ def mainQt(options):
 
     import silx
     from silx.gui import qt
+
     # Make sure matplotlib is configured
     # Needed for Debian 8: compatibility between Qt4/Qt5 and old matplotlib
     import silx.gui.utils.matplotlib  # noqa
@@ -163,7 +145,6 @@ def mainQt(options):
         qt.QApplication.quit()
 
     signal.signal(signal.SIGINT, sigintHandler)
-    sys.excepthook = qt.exceptionHandler
 
     timer = qt.QTimer()
     timer.start(500)
@@ -171,23 +152,30 @@ def mainQt(options):
     # catched
     timer.timeout.connect(lambda: None)
 
-    settings = qt.QSettings(qt.QSettings.IniFormat,
-                            qt.QSettings.UserScope,
-                            "silx",
-                            "silx-view",
-                            None)
+    settings = qt.QSettings(
+        qt.QSettings.IniFormat, qt.QSettings.UserScope, "silx", "silx-view", None
+    )
     if options.fresh_preferences:
         settings.clear()
 
     window = createWindow(parent=None, settings=settings)
     window.setAttribute(qt.Qt.WA_DeleteOnClose, True)
 
+    def exceptHook(type_, value, trace):
+        _logger.error("An error occured in silx view:")
+        _logger.error("%s %s %s", type_, value, "".join(traceback.format_tb(trace)))
+        try:
+            window.setErrorFromException(type_, value, trace)
+        except Exception:
+            pass
+
+    sys.excepthook = exceptHook
+
     if options.use_opengl_plot:
         # It have to be done after the settings (after the Viewer creation)
         silx.config.DEFAULT_PLOT_BACKEND = "opengl"
 
-
-    for url in filesArgToUrls(options.files):
+    for url in parseutils.filenames_to_dataurls(options.files, options.slices):
         # TODO: Would be nice to add a process widget and a cancel button
         try:
             window.appendFile(url.path())
@@ -214,5 +202,5 @@ def main(argv):
     mainQt(options)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main(sys.argv)
