@@ -1,6 +1,6 @@
 # /*##########################################################################
 #
-# Copyright (c) 2017-2021 European Synchrotron Radiation Facility
+# Copyright (c) 2017-2023 European Synchrotron Radiation Facility
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -30,7 +30,6 @@ __authors__ = ["V. Valls"]
 __license__ = "MIT"
 __date__ = "12/02/2019"
 
-import collections
 import functools
 import os.path
 import logging
@@ -39,6 +38,7 @@ import numpy
 
 from silx.gui import qt
 import silx.io
+from silx.io import h5link_utils
 from .TextFormatter import TextFormatter
 import silx.gui.hdf5
 from silx.gui.widgets import HierarchicalTableView
@@ -50,8 +50,8 @@ _logger = logging.getLogger(__name__)
 
 
 class _CellData(object):
-    """Store a table item
-    """
+    """Store a table item"""
+
     def __init__(self, value=None, isHeader=False, span=None, tooltip=None):
         """
         Constructor
@@ -73,8 +73,7 @@ class _CellData(object):
         return self.__isHeader
 
     def value(self):
-        """Returns the value of the item.
-        """
+        """Returns the value of the item."""
         return self.__value
 
     def span(self):
@@ -187,10 +186,18 @@ class _CellFilterAvailableData(_CellData):
 
     _states = {
         True: ("Available", qt.QColor(0x000000), None, None),
-        False: ("Not available", qt.QColor(0xFFFFFF), qt.QColor(0xFF0000),
-                "You have to install this filter on your system to be able to read this dataset"),
-        "na": ("n.a.", qt.QColor(0x000000), None,
-               "This version of h5py/hdf5 is not able to display the information"),
+        False: (
+            "Not available",
+            qt.QColor(0xFFFFFF),
+            qt.QColor(0xFF0000),
+            "You have to install this filter on your system to be able to read this dataset",
+        ),
+        "na": (
+            "n.a.",
+            qt.QColor(0x000000),
+            None,
+            "This version of h5py/hdf5 is not able to display the information",
+        ),
     }
 
     def __init__(self, filterId):
@@ -309,7 +316,9 @@ class Hdf5TableModel(HierarchicalTableView.HierarchicalTableModel):
         if h5pyObject is None or self.isSupportedObject(h5pyObject):
             self.__obj = h5pyObject
         else:
-            _logger.warning("Object class %s unsupported. Object ignored.", type(h5pyObject))
+            _logger.warning(
+                "Object class %s unsupported. Object ignored.", type(h5pyObject)
+            )
         self.__initProperties()
 
         self.endResetModel()
@@ -319,10 +328,12 @@ class Hdf5TableModel(HierarchicalTableView.HierarchicalTableModel):
         return self.__hdf5Formatter.humanReadableHdf5Type(dataset)
 
     def __attributeTooltip(self, attribute):
-        attributeDict = collections.OrderedDict()
+        attributeDict = {}
         if hasattr(attribute, "shape"):
             attributeDict["Shape"] = self.__hdf5Formatter.humanReadableShape(attribute)
-        attributeDict["Data type"] = self.__hdf5Formatter.humanReadableType(attribute, full=True)
+        attributeDict["Data type"] = self.__hdf5Formatter.humanReadableType(
+            attribute, full=True
+        )
         html = htmlFromDict(attributeDict, title="HDF5 Attribute")
         return html
 
@@ -336,7 +347,7 @@ class Hdf5TableModel(HierarchicalTableView.HierarchicalTableModel):
             return self.__hdf5Formatter.humanReadableShape(dataset)
         size = dataset.size
         shape = self.__hdf5Formatter.humanReadableShape(dataset)
-        return u"%s = %s" % (shape, size)
+        return "%s = %s" % (shape, size)
 
     def __formatChunks(self, dataset):
         """Format the shape"""
@@ -344,7 +355,7 @@ class Hdf5TableModel(HierarchicalTableView.HierarchicalTableModel):
         if chunks is None:
             return ""
         shape = " \u00D7 ".join([str(i) for i in chunks])
-        sizes = numpy.product(chunks)
+        sizes = numpy.prod(chunks)
         text = "%s = %s" % (shape, sizes)
         return text
 
@@ -383,7 +394,9 @@ class Hdf5TableModel(HierarchicalTableView.HierarchicalTableModel):
             self.__data.addHeaderValueRow("Local", local)
         else:
             # it's a real H5py object
-            self.__data.addHeaderValueRow("Basename", lambda x: os.path.basename(x.name))
+            self.__data.addHeaderValueRow(
+                "Basename", lambda x: os.path.basename(x.name)
+            )
             self.__data.addHeaderValueRow("Name", lambda x: x.name)
             if obj.file is not None:
                 self.__data.addHeaderValueRow("File", lambda x: x.file.filename)
@@ -399,25 +412,10 @@ class Hdf5TableModel(HierarchicalTableView.HierarchicalTableModel):
                 showPhysicalLocation = False
 
         # External data (nothing to do with external links)
-        nExtSources = 0
-        firstExtSource = None
-        extType = None
-        if silx.io.is_dataset(hdf5obj):
-            if hasattr(hdf5obj, "is_virtual"):
-                if hdf5obj.is_virtual:
-                    extSources = hdf5obj.virtual_sources()
-                    if extSources:
-                        firstExtSource = extSources[0].file_name + SEPARATOR + extSources[0].dset_name
-                        extType = "Virtual"
-                        nExtSources = len(extSources)
-            if hasattr(hdf5obj, "external"):
-                extSources = hdf5obj.external
-                if extSources:
-                    firstExtSource = extSources[0][0]
-                    extType = "Raw"
-                    nExtSources = len(extSources)
+        external_dataset_info = h5link_utils.external_dataset_info(hdf5obj)
 
         if showPhysicalLocation:
+
             def _physical_location(x):
                 if isinstance(obj, silx.gui.hdf5.H5Node):
                     return x.physical_filename + SEPARATOR + x.physical_name
@@ -431,34 +429,15 @@ class Hdf5TableModel(HierarchicalTableView.HierarchicalTableModel):
 
             self.__data.addHeaderValueRow("Physical", _physical_location)
 
-        if extType:
-            def _first_source(x):
-                # Absolute path
-                if os.path.isabs(firstExtSource):
-                    return firstExtSource
-
-                # Relative path with respect to the file directory
-                if isinstance(obj, silx.gui.hdf5.H5Node):
-                    filename = x.physical_filename
-                elif silx.io.is_file(obj):
-                    filename = x.filename
-                elif obj.file is not None:
-                    filename = x.file.filename
-                else:
-                    return firstExtSource
-
-                if firstExtSource[0] == ".":
-                    return filename + firstExtSource[1:]
-                else:
-                    return os.path.join(os.path.dirname(filename), firstExtSource)
-
+        if external_dataset_info is not None:
             self.__data.addHeaderRow(headerLabel="External sources")
-            self.__data.addHeaderValueRow("Type", extType)
-            self.__data.addHeaderValueRow("Count", str(nExtSources))
-            self.__data.addHeaderValueRow("First", _first_source)
+            self.__data.addHeaderValueRow("Type", external_dataset_info.type)
+            self.__data.addHeaderValueRow("Count", external_dataset_info.nfiles)
+            self.__data.addHeaderValueRow(
+                "First", external_dataset_info.first_source_url
+            )
 
         if hasattr(obj, "dtype"):
-
             self.__data.addHeaderRow(headerLabel="Data info")
 
             if hasattr(obj, "id") and hasattr(obj.id, "get_type"):
@@ -500,10 +479,14 @@ class Hdf5TableModel(HierarchicalTableView.HierarchicalTableModel):
                 self.__data.addHeaderRow(headerLabel="Attributes")
                 for key in sorted(obj.attrs.keys()):
                     callback = lambda key, x: self.__formatter.toString(x.attrs[key])
-                    callbackTooltip = lambda key, x: self.__attributeTooltip(x.attrs[key])
-                    self.__data.addHeaderValueRow(headerLabel=key,
-                                                  value=functools.partial(callback, key),
-                                                  tooltip=functools.partial(callbackTooltip, key))
+                    callbackTooltip = lambda key, x: self.__attributeTooltip(
+                        x.attrs[key]
+                    )
+                    self.__data.addHeaderValueRow(
+                        headerLabel=key,
+                        value=functools.partial(callback, key),
+                        tooltip=functools.partial(callbackTooltip, key),
+                    )
 
     def __getFilterInfo(self, dataset, filterIndex):
         """Get a tuple of readable info from dataset filters
@@ -558,8 +541,7 @@ class Hdf5TableModel(HierarchicalTableView.HierarchicalTableModel):
         return self.__formatter
 
     def __formatChanged(self):
-        """Called when the format changed.
-        """
+        """Called when the format changed."""
         self.reset()
 
 
@@ -628,6 +610,11 @@ class Hdf5TableView(HierarchicalTableView.HierarchicalTableView):
         for row in range(model.rowCount()):
             for column in range(model.columnCount()):
                 index = model.index(row, column)
-                if (index.isValid() and index.data(
-                        HierarchicalTableView.HierarchicalTableModel.IsHeaderRole) is False):
+                if (
+                    index.isValid()
+                    and index.data(
+                        HierarchicalTableView.HierarchicalTableModel.IsHeaderRole
+                    )
+                    is False
+                ):
                     self.openPersistentEditor(index)
