@@ -27,8 +27,6 @@ __authors__ = ["P. Knobel"]
 __license__ = "MIT"
 __date__ = "05/12/2016"
 
-import unittest
-
 from silx.gui.utils.testutils import TestCaseQt
 from .. import FitConfig
 
@@ -61,22 +59,24 @@ class TestFitConfig(TestCaseQt):
         self.fit_config.accept()
         output = self.fit_config.output
 
-        for key in ["AutoFwhm",
-                    "PositiveHeightAreaFlag",
-                    "QuotedPositionFlag",
-                    "PositiveFwhmFlag",
-                    "SameFwhmFlag",
-                    "QuotedEtaFlag",
-                    "NoConstraintsFlag",
-                    "FwhmPoints",
-                    "Sensitivity",
-                    "Yscaling",
-                    "ForcePeakPresence",
-                    "StripBackgroundFlag",
-                    "StripWidth",
-                    "StripIterations",
-                    "StripThreshold",
-                    "SmoothingFlag"]:
+        for key in [
+            "AutoFwhm",
+            "PositiveHeightAreaFlag",
+            "QuotedPositionFlag",
+            "PositiveFwhmFlag",
+            "SameFwhmFlag",
+            "QuotedEtaFlag",
+            "NoConstraintsFlag",
+            "FwhmPoints",
+            "Sensitivity",
+            "Yscaling",
+            "ForcePeakPresence",
+            "StripBackgroundFlag",
+            "StripWidth",
+            "StripIterations",
+            "StripThreshold",
+            "SmoothingFlag",
+        ]:
             self.assertIn(key, output)
 
         self.assertTrue(output["AutoFwhm"])
