@@ -33,7 +33,7 @@ __date__ = "17/01/2019"
 from html import escape
 import logging
 import os.path
-
+from silx.gui import constants
 import silx.io.utils
 import silx.io.url
 from .. import qt
@@ -109,19 +109,20 @@ class Hdf5DatasetMimeData(qt.QMimeData):
 
     MIME_TYPE = "application/x-internal-h5py-dataset"
 
-    SILX_URI_TYPE = "application/x-silx-uri"
+    SILX_URI_TYPE = constants.SILX_URI_MIMETYPE
+    """For compatibility with silx <= 1.1"""
 
     def __init__(self, node=None, dataset=None, isRoot=False):
         qt.QMimeData.__init__(self)
         self.__dataset = dataset
         self.__node = node
         self.__isRoot = isRoot
-        self.setData(self.MIME_TYPE, "".encode(encoding='utf-8'))
+        self.setData(self.MIME_TYPE, "".encode(encoding="utf-8"))
         if node is not None:
             h5Node = H5Node(node)
             silxUrl = h5Node.url
             self.setText(silxUrl)
-            self.setData(self.SILX_URI_TYPE, silxUrl.encode(encoding='utf-8'))
+            self.setData(constants.SILX_URI_MIMETYPE, silxUrl.encode(encoding="utf-8"))
 
     def isRoot(self):
         return self.__isRoot
@@ -427,9 +428,9 @@ class H5Node(object):
         :rtype: ~silx.io.url.DataUrl
         """
         absolute_filename = os.path.abspath(self.local_filename)
-        return silx.io.url.DataUrl(scheme="silx",
-                                   file_path=absolute_filename,
-                                   data_path=self.local_name)
+        return silx.io.url.DataUrl(
+            scheme="silx", file_path=absolute_filename, data_path=self.local_name
+        )
 
     @property
     def url(self):
