@@ -1,6 +1,6 @@
 # /*##########################################################################
 #
-# Copyright (c) 2017-2022 European Synchrotron Radiation Facility
+# Copyright (c) 2017-2023 European Synchrotron Radiation Facility
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,16 +23,14 @@
 # ###########################################################################*/
 """This module provides the base class for items of the :class:`Plot`.
 """
+from __future__ import annotations
+
 
 __authors__ = ["T. Vincent"]
 __license__ = "MIT"
 __date__ = "08/12/2020"
 
-import collections
-try:
-    from collections import abc
-except ImportError:  # Python2 support
-    import collections as abc
+from collections import abc
 from copy import deepcopy
 import logging
 import enum
@@ -41,13 +39,12 @@ import weakref
 
 import numpy
 
-from ....utils.deprecation import deprecated
 from ....utils.proxy import docstring
 from ....utils.enum import Enum as _Enum
 from ....math.combo import min_max
 from ... import qt
 from ... import colors
-from ...colors import Colormap
+from ...colors import Colormap, _Colormappable
 from ._pick import PickingResult
 
 from silx import config
@@ -58,98 +55,109 @@ _logger = logging.getLogger(__name__)
 @enum.unique
 class ItemChangedType(enum.Enum):
     """Type of modification provided by :attr:`Item.sigItemChanged` signal."""
+
     # Private setters and setInfo are not emitting sigItemChanged signal.
     # Signals to consider:
     # COLORMAP_SET emitted when setColormap is called but not forward colormap object signal
     # CURRENT_COLOR_CHANGED emitted current color changed because highlight changed,
     # highlighted color changed or color changed depending on hightlight state.
 
-    VISIBLE = 'visibleChanged'
+    VISIBLE = "visibleChanged"
     """Item's visibility changed flag."""
 
-    ZVALUE = 'zValueChanged'
+    ZVALUE = "zValueChanged"
     """Item's Z value changed flag."""
 
-    COLORMAP = 'colormapChanged'  # Emitted when set + forward events from the colormap object
+    COLORMAP = (
+        "colormapChanged"  # Emitted when set + forward events from the colormap object
+    )
     """Item's colormap changed flag.
 
     This is emitted both when setting a new colormap and
     when the current colormap object is updated.
     """
 
-    SYMBOL = 'symbolChanged'
+    SYMBOL = "symbolChanged"
     """Item's symbol changed flag."""
 
-    SYMBOL_SIZE = 'symbolSizeChanged'
+    SYMBOL_SIZE = "symbolSizeChanged"
     """Item's symbol size changed flag."""
 
-    LINE_WIDTH = 'lineWidthChanged'
+    LINE_WIDTH = "lineWidthChanged"
     """Item's line width changed flag."""
 
-    LINE_STYLE = 'lineStyleChanged'
+    LINE_STYLE = "lineStyleChanged"
     """Item's line style changed flag."""
 
-    COLOR = 'colorChanged'
+    COLOR = "colorChanged"
     """Item's color changed flag."""
 
-    LINE_BG_COLOR = 'lineBgColorChanged'
-    """Item's line background color changed flag."""
+    LINE_BG_COLOR = "lineBgColorChanged"  # Deprecated, use LINE_GAP_COLOR
 
-    YAXIS = 'yAxisChanged'
+    LINE_GAP_COLOR = "lineGapColorChanged"
+    """Item's dashed line gap color changed flag."""
+
+    YAXIS = "yAxisChanged"
     """Item's Y axis binding changed flag."""
 
-    FILL = 'fillChanged'
+    FILL = "fillChanged"
     """Item's fill changed flag."""
 
-    ALPHA = 'alphaChanged'
+    ALPHA = "alphaChanged"
     """Item's transparency alpha changed flag."""
 
-    DATA = 'dataChanged'
+    DATA = "dataChanged"
     """Item's data changed flag"""
 
-    MASK = 'maskChanged'
+    MASK = "maskChanged"
     """Item's mask changed flag"""
 
-    HIGHLIGHTED = 'highlightedChanged'
+    HIGHLIGHTED = "highlightedChanged"
     """Item's highlight state changed flag."""
 
-    HIGHLIGHTED_COLOR = 'highlightedColorChanged'
+    HIGHLIGHTED_COLOR = "highlightedColorChanged"
     """Deprecated, use HIGHLIGHTED_STYLE instead."""
 
-    HIGHLIGHTED_STYLE = 'highlightedStyleChanged'
+    HIGHLIGHTED_STYLE = "highlightedStyleChanged"
     """Item's highlighted style changed flag."""
 
-    SCALE = 'scaleChanged'
+    SCALE = "scaleChanged"
     """Item's scale changed flag."""
 
-    TEXT = 'textChanged'
+    TEXT = "textChanged"
     """Item's text changed flag."""
 
-    POSITION = 'positionChanged'
+    POSITION = "positionChanged"
     """Item's position changed flag.
 
     This is emitted when a marker position changed and
     when an image origin changed.
     """
 
-    OVERLAY = 'overlayChanged'
+    OVERLAY = "overlayChanged"
     """Item's overlay state changed flag."""
 
-    VISUALIZATION_MODE = 'visualizationModeChanged'
+    VISUALIZATION_MODE = "visualizationModeChanged"
     """Item's visualization mode changed flag."""
 
-    COMPLEX_MODE = 'complexModeChanged'
+    COMPLEX_MODE = "complexModeChanged"
     """Item's complex data visualization mode changed flag."""
 
-    NAME = 'nameChanged'
+    NAME = "nameChanged"
     """Item's name changed flag."""
 
-    EDITABLE = 'editableChanged'
+    EDITABLE = "editableChanged"
     """Item's editable state changed flags."""
 
-    SELECTABLE = 'selectableChanged'
+    SELECTABLE = "selectableChanged"
     """Item's selectable state changed flags."""
 
+    FONT = "fontChanged"
+    """Item's text font changed flag."""
+
+    BACKGROUND_COLOR = "backgroundColorChanged"
+    """Item's text background color changed flag."""
+
 
 class Item(qt.QObject):
     """Description of an item of the plot"""
@@ -184,7 +192,7 @@ class Item(qt.QObject):
         self._info = None
         self._xlabel = None
         self._ylabel = None
-        self.__name = ''
+        self.__name = ""
 
         self.__visibleBoundsTracking = False
         self.__previousVisibleBounds = None
@@ -206,7 +214,7 @@ class Item(qt.QObject):
         :param Union[~silx.gui.plot.PlotWidget,None] plot: The Plot instance.
         """
         if plot is not None and self._plotRef is not None:
-            raise RuntimeError('Trying to add a node at two places.')
+            raise RuntimeError("Trying to add a node at two places.")
         self.__disconnectFromPlotWidget()
         self._plotRef = None if plot is None else weakref.ref(plot)
         self.__connectToPlotWidget()
@@ -240,8 +248,7 @@ class Item(qt.QObject):
         if visible != self._visible:
             self._visible = visible
             # When visibility has changed, always mark as dirty
-            self._updated(ItemChangedType.VISIBLE,
-                          checkVisibility=False)
+            self._updated(ItemChangedType.VISIBLE, checkVisibility=False)
             if visible:
                 self._visibleBoundsChanged()
 
@@ -268,8 +275,7 @@ class Item(qt.QObject):
         name = str(name)
         if self.__name != name:
             if self.getPlot() is not None:
-                raise RuntimeError(
-                    "Cannot change name while item is in a PlotWidget")
+                raise RuntimeError("Cannot change name while item is in a PlotWidget")
 
             self.__name = name
             self._updated(ItemChangedType.NAME)
@@ -277,11 +283,6 @@ class Item(qt.QObject):
     def getLegend(self):  # Replaced by getName for API consistency
         return self.getName()
 
-    @deprecated(replacement='setName', since_version='0.13')
-    def _setLegend(self, legend):
-        legend = str(legend) if legend is not None else ''
-        self.setName(legend)
-
     def isSelectable(self):
         """Returns true if item is selectable (bool)"""
         return self._selectable
@@ -332,7 +333,8 @@ class Item(qt.QObject):
 
         xmin, xmax = numpy.clip(bounds[:2], *plot.getXAxis().getLimits())
         ymin, ymax = numpy.clip(
-            bounds[2:], *plot.getYAxis(self.__getYAxis()).getLimits())
+            bounds[2:], *plot.getYAxis(self.__getYAxis()).getLimits()
+        )
 
         if xmin == xmax or ymin == ymax:  # Outside the plot area
             return None
@@ -360,7 +362,7 @@ class Item(qt.QObject):
 
     def __getYAxis(self) -> str:
         """Returns current Y axis ('left' or 'right')"""
-        return self.getYAxis() if isinstance(self, YAxisMixIn) else 'left'
+        return self.getYAxis() if isinstance(self, YAxisMixIn) else "left"
 
     def __connectToPlotWidget(self) -> None:
         """Connect to PlotWidget signals and install event filter"""
@@ -486,7 +488,7 @@ class Item(qt.QObject):
 class DataItem(Item):
     """Item with a data extent in the plot"""
 
-    def _boundsChanged(self, checkVisibility: bool=True) -> None:
+    def _boundsChanged(self, checkVisibility: bool = True) -> None:
         """Call this method in subclass when data bounds has changed.
 
         :param bool checkVisibility:
@@ -506,6 +508,7 @@ class DataItem(Item):
             self._boundsChanged(checkVisibility=False)
         super().setVisible(visible)
 
+
 # Mix-in classes ##############################################################
 
 
@@ -522,8 +525,7 @@ class ItemMixInBase(object):
         :param bool checkVisibility: True to only mark as dirty if visible,
                                      False to always mark as dirty.
         """
-        raise RuntimeError(
-            "Issue with Mix-In class inheritance order")
+        raise RuntimeError("Issue with Mix-In class inheritance order")
 
 
 class LabelsMixIn(ItemMixInBase):
@@ -597,7 +599,7 @@ class DraggableMixIn(ItemMixInBase):
         raise NotImplementedError("Must be implemented in subclass")
 
 
-class ColormapMixIn(ItemMixInBase):
+class ColormapMixIn(_Colormappable, ItemMixInBase):
     """Mix-in class for items with colormap"""
 
     def __init__(self):
@@ -631,8 +633,9 @@ class ColormapMixIn(ItemMixInBase):
         """Handle updates of the colormap"""
         self._updated(ItemChangedType.COLORMAP)
 
-    def _setColormappedData(self, data, copy=True,
-                            min_=None, minPositive=None, max_=None):
+    def _setColormappedData(
+        self, data, copy=True, min_=None, minPositive=None, max_=None
+    ):
         """Set the data used to compute the colormapped display.
 
         It also resets the cache of data ranges.
@@ -653,7 +656,10 @@ class ColormapMixIn(ItemMixInBase):
             if min_ is not None and numpy.isfinite(min_):
                 self.__cacheColormapRange[Colormap.LINEAR, Colormap.MINMAX] = min_, max_
             if minPositive is not None and numpy.isfinite(minPositive):
-                self.__cacheColormapRange[Colormap.LOGARITHM, Colormap.MINMAX] = minPositive, max_
+                self.__cacheColormapRange[Colormap.LOGARITHM, Colormap.MINMAX] = (
+                    minPositive,
+                    max_,
+                )
 
         colormap = self.getColormap()
         if None in (colormap.getVMin(), colormap.getVMax()):
@@ -705,26 +711,29 @@ class SymbolMixIn(ItemMixInBase):
     _DEFAULT_SYMBOL_SIZE = config.DEFAULT_PLOT_SYMBOL_SIZE
     """Default marker size of the item"""
 
-    _SUPPORTED_SYMBOLS = collections.OrderedDict((
-        ('o', 'Circle'),
-        ('d', 'Diamond'),
-        ('s', 'Square'),
-        ('+', 'Plus'),
-        ('x', 'Cross'),
-        ('.', 'Point'),
-        (',', 'Pixel'),
-        ('|', 'Vertical line'),
-        ('_', 'Horizontal line'),
-        ('tickleft', 'Tick left'),
-        ('tickright', 'Tick right'),
-        ('tickup', 'Tick up'),
-        ('tickdown', 'Tick down'),
-        ('caretleft', 'Caret left'),
-        ('caretright', 'Caret right'),
-        ('caretup', 'Caret up'),
-        ('caretdown', 'Caret down'),
-        (u'\u2665', 'Heart'),
-        ('', 'None')))
+    _SUPPORTED_SYMBOLS = dict(
+        (
+            ("o", "Circle"),
+            ("d", "Diamond"),
+            ("s", "Square"),
+            ("+", "Plus"),
+            ("x", "Cross"),
+            (".", "Point"),
+            (",", "Pixel"),
+            ("|", "Vertical line"),
+            ("_", "Horizontal line"),
+            ("tickleft", "Tick left"),
+            ("tickright", "Tick right"),
+            ("tickup", "Tick up"),
+            ("tickdown", "Tick down"),
+            ("caretleft", "Caret left"),
+            ("caretright", "Caret right"),
+            ("caretup", "Caret up"),
+            ("caretdown", "Caret down"),
+            ("\u2665", "Heart"),
+            ("", "None"),
+        )
+    )
     """Dict of supported symbols"""
 
     def __init__(self):
@@ -799,7 +808,7 @@ class SymbolMixIn(ItemMixInBase):
                     symbol = symbolCode
                     break
             else:
-                raise ValueError('Unsupported symbol %s' % str(symbol))
+                raise ValueError("Unsupported symbol %s" % str(symbol))
 
         if symbol != self._symbol:
             self._symbol = symbol
@@ -826,50 +835,74 @@ class SymbolMixIn(ItemMixInBase):
             self._updated(ItemChangedType.SYMBOL_SIZE)
 
 
+LineStyleType = Union[
+    str,
+    Tuple[Union[float, int], None],
+    Tuple[Union[float, int], Tuple[Union[float, int], Union[float, int]]],
+    Tuple[Union[float, int], Tuple[Union[float, int], Union[float, int], Union[float, int], Union[float, int]]],
+]
+"""Type for :class:`LineMixIn`'s line style"""
+
+
 class LineMixIn(ItemMixInBase):
     """Mix-in class for item with line"""
 
-    _DEFAULT_LINEWIDTH = 1.
+    _DEFAULT_LINEWIDTH: float = 1.0
     """Default line width"""
 
-    _DEFAULT_LINESTYLE = '-'
+    _DEFAULT_LINESTYLE: LineStyleType = "-"
     """Default line style"""
 
-    _SUPPORTED_LINESTYLE = '', ' ', '-', '--', '-.', ':', None
+    _SUPPORTED_LINESTYLE = "", " ", "-", "--", "-.", ":", None
     """Supported line styles"""
 
     def __init__(self):
-        self._linewidth = self._DEFAULT_LINEWIDTH
-        self._linestyle = self._DEFAULT_LINESTYLE
+        self._linewidth: float = self._DEFAULT_LINEWIDTH
+        self._linestyle: LineStyleType = self._DEFAULT_LINESTYLE
 
     @classmethod
-    def getSupportedLineStyles(cls):
-        """Returns list of supported line styles.
-
-        :rtype: List[str,None]
-        """
+    def getSupportedLineStyles(cls) -> tuple[str | None]:
+        """Returns list of supported constant line styles."""
         return cls._SUPPORTED_LINESTYLE
 
-    def getLineWidth(self):
-        """Return the curve line width in pixels
-
-        :rtype: float
-        """
+    def getLineWidth(self) -> float:
+        """Return the curve line width in pixels"""
         return self._linewidth
 
-    def setLineWidth(self, width):
+    def setLineWidth(self, width: float):
         """Set the width in pixel of the curve line
 
         See :meth:`getLineWidth`.
-
-        :param float width: Width in pixels
         """
         width = float(width)
         if width != self._linewidth:
             self._linewidth = width
             self._updated(ItemChangedType.LINE_WIDTH)
 
-    def getLineStyle(self):
+    @classmethod
+    def isValidLineStyle(cls, style: LineStyleType | None) -> bool:
+        """Returns True for valid styles"""
+        if style is None or style in cls.getSupportedLineStyles():
+            return True
+        if not isinstance(style, tuple):
+            return False
+        if (
+            len(style) == 2
+            and isinstance(style[0], (float, int))
+            and (
+                style[1] is None
+                or style[1] == ()
+                or (
+                    isinstance(style[1], tuple)
+                    and len(style[1]) in (2, 4)
+                    and all(map(lambda item: isinstance(item, (float, int)), style[1]))
+                )
+            )
+        ):
+            return True
+        return False
+
+    def getLineStyle(self) -> LineStyleType:
         """Return the type of the line
 
         Type of line::
@@ -879,20 +912,19 @@ class LineMixIn(ItemMixInBase):
             - '--' dashed line
             - '-.' dash-dot line
             - ':'  dotted line
-
-        :rtype: str
+            - (offset, (dash pattern))
         """
         return self._linestyle
 
-    def setLineStyle(self, style):
+    def setLineStyle(self, style: LineStyleType | None):
         """Set the style of the curve line.
 
         See :meth:`getLineStyle`.
 
-        :param str style: Line style
+        :param style: Line style
         """
-        style = str(style)
-        assert style in self.getSupportedLineStyles()
+        if not self.isValidLineStyle(style):
+            raise ValueError(f"No a valid line style: {style}")
         if style is None:
             style = self._DEFAULT_LINESTYLE
         if style != self._linestyle:
@@ -903,7 +935,7 @@ class LineMixIn(ItemMixInBase):
 class ColorMixIn(ItemMixInBase):
     """Mix-in class for item with color"""
 
-    _DEFAULT_COLOR = (0., 0., 0., 1.)
+    _DEFAULT_COLOR = (0.0, 0.0, 0.0, 1.0)
     """Default color of the item"""
 
     def __init__(self):
@@ -941,10 +973,43 @@ class ColorMixIn(ItemMixInBase):
         self._updated(ItemChangedType.COLOR)
 
 
+class LineGapColorMixIn(ItemMixInBase):
+    """Mix-in class for dashed line gap color"""
+
+    _DEFAULT_LINE_GAP_COLOR = None
+    """Default dashed line gap color of the item"""
+
+    def __init__(self):
+        self.__lineGapColor = self._DEFAULT_LINE_GAP_COLOR
+
+    def getLineGapColor(self):
+        """Returns the RGBA color of dashed line gap of the item
+
+        :rtype: 4-tuple of float in [0, 1] or None
+        """
+        return self.__lineGapColor
+
+    def setLineGapColor(self, color):
+        """Set dashed line gap color
+
+        It supports:
+        - color names: e.g., 'green'
+        - color codes: '#RRGGBB' and '#RRGGBBAA'
+        - indexed color names: e.g., 'C0'
+        - RGB(A) sequence of uint8 in [0, 255] or float in [0, 1]
+        - QColor
+
+        :param color: line background color to be used
+        :type color: Union[str, List[int], List[float], QColor, None]
+        """
+        self.__lineGapColor = None if color is None else colors.rgba(color)
+        self._updated(ItemChangedType.LINE_GAP_COLOR)
+
+
 class YAxisMixIn(ItemMixInBase):
     """Mix-in class for item with yaxis"""
 
-    _DEFAULT_YAXIS = 'left'
+    _DEFAULT_YAXIS = "left"
     """Default Y axis the item belongs to"""
 
     def __init__(self):
@@ -965,7 +1030,7 @@ class YAxisMixIn(ItemMixInBase):
         :param str yaxis: 'left' or 'right'
         """
         yaxis = str(yaxis)
-        assert yaxis in ('left', 'right')
+        assert yaxis in ("left", "right")
         if yaxis != self._yaxis:
             self._yaxis = yaxis
             # Handle data extent changed for DataItem
@@ -977,11 +1042,13 @@ class YAxisMixIn(ItemMixInBase):
                 # Switch Y axis signal connection
                 plot = self.getPlot()
                 if plot is not None:
-                    previousYAxis = 'left' if self.getXAxis() == 'right' else 'right'
+                    previousYAxis = "left" if self.getXAxis() == "right" else "right"
                     plot.getYAxis(previousYAxis).sigLimitsChanged.disconnect(
-                        self._visibleBoundsChanged)
+                        self._visibleBoundsChanged
+                    )
                     plot.getYAxis(self.getYAxis()).sigLimitsChanged.connect(
-                        self._visibleBoundsChanged)
+                        self._visibleBoundsChanged
+                    )
                 self._visibleBoundsChanged()
 
             self._updated(ItemChangedType.YAXIS)
@@ -1015,7 +1082,7 @@ class AlphaMixIn(ItemMixInBase):
     """Mix-in class for item with opacity"""
 
     def __init__(self):
-        self._alpha = 1.
+        self._alpha = 1.0
 
     def getAlpha(self):
         """Returns the opacity of the item
@@ -1038,7 +1105,7 @@ class AlphaMixIn(ItemMixInBase):
         :type alpha: float
         """
         alpha = float(alpha)
-        alpha = max(0., min(alpha, 1.))  # Clip alpha to [0., 1.] range
+        alpha = max(0.0, min(alpha, 1.0))  # Clip alpha to [0., 1.] range
         if alpha != self._alpha:
             self._alpha = alpha
             self._updated(ItemChangedType.ALPHA)
@@ -1052,14 +1119,15 @@ class ComplexMixIn(ItemMixInBase):
 
     class ComplexMode(_Enum):
         """Identify available display mode for complex"""
-        NONE = 'none'
-        ABSOLUTE = 'amplitude'
-        PHASE = 'phase'
-        REAL = 'real'
-        IMAGINARY = 'imaginary'
-        AMPLITUDE_PHASE = 'amplitude_phase'
-        LOG10_AMPLITUDE_PHASE = 'log10_amplitude_phase'
-        SQUARE_AMPLITUDE = 'square_amplitude'
+
+        NONE = "none"
+        ABSOLUTE = "amplitude"
+        PHASE = "phase"
+        REAL = "real"
+        IMAGINARY = "imaginary"
+        AMPLITUDE_PHASE = "amplitude_phase"
+        LOG10_AMPLITUDE_PHASE = "log10_amplitude_phase"
+        SQUARE_AMPLITUDE = "square_amplitude"
 
     def __init__(self):
         self.__complex_mode = self.ComplexMode.ABSOLUTE
@@ -1115,7 +1183,7 @@ class ComplexMixIn(ItemMixInBase):
         elif mode is self.ComplexMode.SQUARE_AMPLITUDE:
             return numpy.absolute(data) ** 2
         else:
-            raise ValueError('Unsupported conversion mode: %s', str(mode))
+            raise ValueError("Unsupported conversion mode: %s", str(mode))
 
     @classmethod
     def supportedComplexModes(cls):
@@ -1141,22 +1209,22 @@ class ScatterVisualizationMixIn(ItemMixInBase):
     class Visualization(_Enum):
         """Different modes of scatter plot visualizations"""
 
-        POINTS = 'points'
+        POINTS = "points"
         """Display scatter plot as a point cloud"""
 
-        LINES = 'lines'
+        LINES = "lines"
         """Display scatter plot as a wireframe.
 
         This is based on Delaunay triangulation
         """
 
-        SOLID = 'solid'
+        SOLID = "solid"
         """Display scatter plot as a set of filled triangles.
 
         This is based on Delaunay triangulation
         """
 
-        REGULAR_GRID = 'regular_grid'
+        REGULAR_GRID = "regular_grid"
         """Display scatter plot as an image.
 
         It expects the points to be the intersection of a regular grid,
@@ -1165,7 +1233,7 @@ class ScatterVisualizationMixIn(ItemMixInBase):
         (either all lines from left to right or all from right to left).
         """
 
-        IRREGULAR_GRID = 'irregular_grid'
+        IRREGULAR_GRID = "irregular_grid"
         """Display scatter plot as contiguous quadrilaterals.
 
         It expects the points to be the intersection of an irregular grid,
@@ -1174,7 +1242,7 @@ class ScatterVisualizationMixIn(ItemMixInBase):
         (either all lines from left to right or all from right to left).
         """
 
-        BINNED_STATISTIC = 'binned_statistic'
+        BINNED_STATISTIC = "binned_statistic"
         """Display scatter plot as 2D binned statistic (i.e., generalized histogram).
         """
 
@@ -1182,13 +1250,13 @@ class ScatterVisualizationMixIn(ItemMixInBase):
     class VisualizationParameter(_Enum):
         """Different parameter names for scatter plot visualizations"""
 
-        GRID_MAJOR_ORDER = 'grid_major_order'
+        GRID_MAJOR_ORDER = "grid_major_order"
         """The major order of points in the regular grid.
 
         Either 'row' (row-major, fast X) or 'column' (column-major, fast Y).
         """
 
-        GRID_BOUNDS = 'grid_bounds'
+        GRID_BOUNDS = "grid_bounds"
         """The expected range in data coordinates of the regular grid.
 
         A 2-tuple of 2-tuple: (begin (x, y), end (x, y)).
@@ -1197,24 +1265,24 @@ class ScatterVisualizationMixIn(ItemMixInBase):
         As for `GRID_SHAPE`, this can be wider than the current data.
         """
 
-        GRID_SHAPE = 'grid_shape'
+        GRID_SHAPE = "grid_shape"
         """The expected size of the regular grid (height, width).
 
         The given shape can be wider than the number of points,
         in which case the grid is not fully filled.
         """
 
-        BINNED_STATISTIC_SHAPE = 'binned_statistic_shape'
+        BINNED_STATISTIC_SHAPE = "binned_statistic_shape"
         """The number of bins in each dimension (height, width).
         """
 
-        BINNED_STATISTIC_FUNCTION = 'binned_statistic_function'
+        BINNED_STATISTIC_FUNCTION = "binned_statistic_function"
         """The reduction function to apply to each bin (str).
 
         Available reduction functions are: 'mean' (default), 'count', 'sum'.
         """
 
-        DATA_BOUNDS_HINT = 'data_bounds_hint'
+        DATA_BOUNDS_HINT = "data_bounds_hint"
         """The expected bounds of the data in data coordinates.
 
         A 2-tuple of 2-tuple: ((ymin, ymax), (xmin, xmax)).
@@ -1225,8 +1293,8 @@ class ScatterVisualizationMixIn(ItemMixInBase):
         """
 
     _SUPPORTED_VISUALIZATION_PARAMETER_VALUES = {
-        VisualizationParameter.GRID_MAJOR_ORDER: ('row', 'column'),
-        VisualizationParameter.BINNED_STATISTIC_FUNCTION: ('mean', 'count', 'sum'),
+        VisualizationParameter.GRID_MAJOR_ORDER: ("row", "column"),
+        VisualizationParameter.BINNED_STATISTIC_FUNCTION: ("mean", "count", "sum"),
     }
     """Supported visualization parameter values.
 
@@ -1235,9 +1303,12 @@ class ScatterVisualizationMixIn(ItemMixInBase):
 
     def __init__(self):
         self.__visualization = self.Visualization.POINTS
-        self.__parameters = dict(# Init parameters to None
-            (parameter, None) for parameter in self.VisualizationParameter)
-        self.__parameters[self.VisualizationParameter.BINNED_STATISTIC_FUNCTION] = 'mean'
+        self.__parameters = dict(  # Init parameters to None
+            (parameter, None) for parameter in self.VisualizationParameter
+        )
+        self.__parameters[
+            self.VisualizationParameter.BINNED_STATISTIC_FUNCTION
+        ] = "mean"
 
     @classmethod
     def supportedVisualizations(cls):
@@ -1263,8 +1334,7 @@ class ScatterVisualizationMixIn(ItemMixInBase):
         :returns: tuple of supported of values or None if not defined.
         """
         parameter = cls.VisualizationParameter(parameter)
-        return cls._SUPPORTED_VISUALIZATION_PARAMETER_VALUES.get(
-            parameter, None)
+        return cls._SUPPORTED_VISUALIZATION_PARAMETER_VALUES.get(parameter, None)
 
     def setVisualization(self, mode):
         """Set the scatter plot visualization mode to use.
@@ -1351,6 +1421,7 @@ class ScatterVisualizationMixIn(ItemMixInBase):
 
 class PointsBase(DataItem, SymbolMixIn, AlphaMixIn):
     """Base class for :class:`Curve` and :class:`Scatter`"""
+
     # note: _logFilterData must be overloaded if you overload
     #       getData to change its signature
 
@@ -1398,22 +1469,18 @@ class PointsBase(DataItem, SymbolMixIn, AlphaMixIn):
             errorClipped[mask] = valueMinusError[mask] <= 0
 
             if numpy.any(errorClipped):  # Need filtering
-
                 # expand errorbars to 2xN
                 if error.size == 1:  # Scalar
-                    error = numpy.full(
-                        (2, len(value)), error, dtype=numpy.float64)
+                    error = numpy.full((2, len(value)), error, dtype=numpy.float64)
 
                 elif error.ndim == 1:  # N array
-                    newError = numpy.empty((2, len(value)),
-                                           dtype=numpy.float64)
-                    newError[0,:] = error
-                    newError[1,:] = error
+                    newError = numpy.empty((2, len(value)), dtype=numpy.float64)
+                    newError[0, :] = error
+                    newError[1, :] = error
                     error = newError
 
                 elif error.size == 2 * len(value):  # 2xN array
-                    error = numpy.array(
-                        error, copy=True, dtype=numpy.float64)
+                    error = numpy.array(error, copy=True, dtype=numpy.float64)
 
                 else:
                     _logger.error("Unhandled error array")
@@ -1437,16 +1504,17 @@ class PointsBase(DataItem, SymbolMixIn, AlphaMixIn):
 
             if xPositive:
                 x = self.getXData(copy=False)
-                with numpy.errstate(invalid='ignore'):  # Ignore NaN warnings
+                with numpy.errstate(invalid="ignore"):  # Ignore NaN warnings
                     xclipped = x <= 0
 
             if yPositive:
                 y = self.getYData(copy=False)
-                with numpy.errstate(invalid='ignore'):  # Ignore NaN warnings
+                with numpy.errstate(invalid="ignore"):  # Ignore NaN warnings
                     yclipped = y <= 0
 
-            self._clippedCache[(xPositive, yPositive)] = \
-                numpy.logical_or(xclipped, yclipped)
+            self._clippedCache[(xPositive, yPositive)] = numpy.logical_or(
+                xclipped, yclipped
+            )
         return self._clippedCache[(xPositive, yPositive)]
 
     def _logFilterData(self, xPositive, yPositive):
@@ -1484,7 +1552,7 @@ class PointsBase(DataItem, SymbolMixIn, AlphaMixIn):
     def __minMaxDataWithError(
         data: numpy.ndarray,
         error: Optional[Union[float, numpy.ndarray]],
-        positiveOnly: bool
+        positiveOnly: bool,
     ) -> Tuple[float]:
         if error is None:
             min_, max_ = min_max(data, finite=True)
@@ -1532,9 +1600,12 @@ class PointsBase(DataItem, SymbolMixIn, AlphaMixIn):
             xmin, xmax = self.__minMaxDataWithError(x, xerror, xPositive)
             ymin, ymax = self.__minMaxDataWithError(y, yerror, yPositive)
 
-            self._boundsCache[(xPositive, yPositive)] = tuple([
-                (bound if bound is not None else numpy.nan)
-                for bound in (xmin, xmax, ymin, ymax)])
+            self._boundsCache[(xPositive, yPositive)] = tuple(
+                [
+                    (bound if bound is not None else numpy.nan)
+                    for bound in (xmin, xmax, ymin, ymax)
+                ]
+            )
         return self._boundsCache[(xPositive, yPositive)]
 
     def _getCachedData(self):
@@ -1548,8 +1619,9 @@ class PointsBase(DataItem, SymbolMixIn, AlphaMixIn):
             if xPositive or yPositive:
                 # At least one axis has log scale, filter data
                 if (xPositive, yPositive) not in self._filteredCache:
-                    self._filteredCache[(xPositive, yPositive)] = \
-                        self._logFilterData(xPositive, yPositive)
+                    self._filteredCache[(xPositive, yPositive)] = self._logFilterData(
+                        xPositive, yPositive
+                    )
                 return self._filteredCache[(xPositive, yPositive)]
         return None
 
@@ -1570,10 +1642,12 @@ class PointsBase(DataItem, SymbolMixIn, AlphaMixIn):
             if cached_data is not None:
                 return cached_data
 
-        return (self.getXData(copy),
-                self.getYData(copy),
-                self.getXErrorData(copy),
-                self.getYErrorData(copy))
+        return (
+            self.getXData(copy),
+            self.getYData(copy),
+            self.getXErrorData(copy),
+            self.getYErrorData(copy),
+        )
 
     def getXData(self, copy=True):
         """Returns the x coordinates of the data points
@@ -1640,12 +1714,10 @@ class PointsBase(DataItem, SymbolMixIn, AlphaMixIn):
 
         # Convert complex data
         if numpy.iscomplexobj(x):
-            _logger.warning(
-                'Converting x data to absolute value to plot it.')
+            _logger.warning("Converting x data to absolute value to plot it.")
             x = numpy.absolute(x)
         if numpy.iscomplexobj(y):
-            _logger.warning(
-                'Converting y data to absolute value to plot it.')
+            _logger.warning("Converting y data to absolute value to plot it.")
             y = numpy.absolute(y)
 
         if xerror is not None:
@@ -1653,7 +1725,8 @@ class PointsBase(DataItem, SymbolMixIn, AlphaMixIn):
                 xerror = numpy.array(xerror, copy=copy)
                 if numpy.iscomplexobj(xerror):
                     _logger.warning(
-                        'Converting xerror data to absolute value to plot it.')
+                        "Converting xerror data to absolute value to plot it."
+                    )
                     xerror = numpy.absolute(xerror)
             else:
                 xerror = float(xerror)
@@ -1662,7 +1735,8 @@ class PointsBase(DataItem, SymbolMixIn, AlphaMixIn):
                 yerror = numpy.array(yerror, copy=copy)
                 if numpy.iscomplexobj(yerror):
                     _logger.warning(
-                        'Converting yerror data to absolute value to plot it.')
+                        "Converting yerror data to absolute value to plot it."
+                    )
                     yerror = numpy.absolute(yerror)
             else:
                 yerror = float(yerror)
@@ -1691,7 +1765,7 @@ class BaselineMixIn(object):
         :param baseline: baseline value(s)
         :type: Union[None,float,numpy.ndarray]
         """
-        if (isinstance(baseline, abc.Iterable)):
+        if isinstance(baseline, abc.Iterable):
             baseline = numpy.array(baseline)
         self._baseline = baseline
 
@@ -1713,7 +1787,6 @@ class _Style:
 
 
 class HighlightedMixIn(ItemMixInBase):
-
     def __init__(self):
         self._highlightStyle = self._DEFAULT_HIGHLIGHT_STYLE
         self._highlighted = False
