@@ -30,7 +30,6 @@ __date__ = "17/01/2018"
 
 import logging
 import os.path
-import unittest
 
 import numpy
 
@@ -41,8 +40,6 @@ from silx.gui.utils.testutils import getQToolButtonFromAction
 from silx.gui.plot import PlotWindow, MaskToolsWidget
 from .utils import PlotWidgetTestCase
 
-import fabio
-
 
 _logger = logging.getLogger(__name__)
 
@@ -55,7 +52,7 @@ class TestMaskToolsWidget(PlotWidgetTestCase, ParametricTestCase):
 
     def setUp(self):
         super(TestMaskToolsWidget, self).setUp()
-        self.widget = MaskToolsWidget.MaskToolsDockWidget(plot=self.plot, name='TEST')
+        self.widget = MaskToolsWidget.MaskToolsDockWidget(plot=self.plot, name="TEST")
         self.plot.addDockWidget(qt.Qt.BottomDockWidgetArea, self.widget)
         self.maskWidget = self.widget.widget()
 
@@ -66,10 +63,10 @@ class TestMaskToolsWidget(PlotWidgetTestCase, ParametricTestCase):
 
     def testEmptyPlot(self):
         """Empty plot, display MaskToolsDockWidget, toggle multiple masks"""
-        self.maskWidget.setMultipleMasks('single')
+        self.maskWidget.setMultipleMasks("single")
         self.qapp.processEvents()
 
-        self.maskWidget.setMultipleMasks('exclusive')
+        self.maskWidget.setMultipleMasks("exclusive")
         self.qapp.processEvents()
 
     def _drag(self):
@@ -99,12 +96,14 @@ class TestMaskToolsWidget(PlotWidgetTestCase, ParametricTestCase):
         x, y = plot.width() // 2, plot.height() // 2
         offset = min(plot.width(), plot.height()) // 10
 
-        star = [(x, y + offset),
-                (x - offset, y - offset),
-                (x + offset, y),
-                (x - offset, y),
-                (x + offset, y - offset),
-                (x, y + offset)]  # Close polygon
+        star = [
+            (x, y + offset),
+            (x - offset, y - offset),
+            (x + offset, y),
+            (x - offset, y),
+            (x + offset, y - offset),
+            (x, y + offset),
+        ]  # Close polygon
 
         self.mouseMove(plot, pos=(0, 0))
         for pos in star:
@@ -121,28 +120,33 @@ class TestMaskToolsWidget(PlotWidgetTestCase, ParametricTestCase):
         x, y = plot.width() // 2, plot.height() // 2
         offset = min(plot.width(), plot.height()) // 10
 
-        star = [(x, y + offset),
-                (x - offset, y - offset),
-                (x + offset, y),
-                (x - offset, y),
-                (x + offset, y - offset)]
+        star = [
+            (x, y + offset),
+            (x - offset, y - offset),
+            (x + offset, y),
+            (x - offset, y),
+            (x + offset, y - offset),
+        ]
 
         self.mouseMove(plot, pos=(0, 0))
         for start, end in zip(star[:-1], star[1:]):
-           self.mouseMove(plot, pos=start)
-           self.mousePress(plot, qt.Qt.LeftButton, pos=start)
-           self.qapp.processEvents()
-           self.mouseMove(plot, pos=end)
-           self.qapp.processEvents()
-           self.mouseRelease(plot, qt.Qt.LeftButton, pos=end)
-           self.qapp.processEvents()
+            self.mouseMove(plot, pos=start)
+            self.mousePress(plot, qt.Qt.LeftButton, pos=start)
+            self.qapp.processEvents()
+            self.mouseMove(plot, pos=end)
+            self.qapp.processEvents()
+            self.mouseRelease(plot, qt.Qt.LeftButton, pos=end)
+            self.qapp.processEvents()
 
     def _isMaskItemSync(self):
         """Check if masks from item and tools are sync or not"""
         if self.maskWidget.isItemMaskUpdated():
-            return numpy.all(numpy.equal(
-                self.maskWidget.getSelectionMask(),
-                self.plot.getActiveImage().getMaskData(copy=False)))
+            return numpy.all(
+                numpy.equal(
+                    self.maskWidget.getSelectionMask(),
+                    self.plot.getActiveImage().getMaskData(copy=False),
+                )
+            )
         else:
             return True
 
@@ -150,30 +154,36 @@ class TestMaskToolsWidget(PlotWidgetTestCase, ParametricTestCase):
         """Plot with an image: test MaskToolsWidget interactions"""
 
         # Add and remove a image (this should enable/disable GUI + change mask)
-        self.plot.addImage(numpy.random.random(1024**2).reshape(1024, 1024),
-                           legend='test')
+        self.plot.addImage(
+            numpy.random.random(1024**2).reshape(1024, 1024), legend="test"
+        )
         self.qapp.processEvents()
 
-        self.plot.remove('test', kind='image')
+        self.plot.remove("test", kind="image")
         self.qapp.processEvents()
 
-        tests = [((0, 0), (1, 1)),
-                 ((1000, 1000), (1, 1)),
-                 ((0, 0), (-1, -1)),
-                 ((1000, 1000), (-1, -1))]
+        tests = [
+            ((0, 0), (1, 1)),
+            ((1000, 1000), (1, 1)),
+            ((0, 0), (-1, -1)),
+            ((1000, 1000), (-1, -1)),
+        ]
 
         for itemMaskUpdated in (False, True):
             for origin, scale in tests:
                 with self.subTest(origin=origin, scale=scale):
                     self.maskWidget.setItemMaskUpdated(itemMaskUpdated)
-                    self.plot.addImage(numpy.arange(1024**2).reshape(1024, 1024),
-                                       legend='test',
-                                       origin=origin,
-                                       scale=scale)
+                    self.plot.addImage(
+                        numpy.arange(1024**2).reshape(1024, 1024),
+                        legend="test",
+                        origin=origin,
+                        scale=scale,
+                    )
                     self.qapp.processEvents()
 
                     self.assertEqual(
-                        self.maskWidget.isItemMaskUpdated(), itemMaskUpdated)
+                        self.maskWidget.isItemMaskUpdated(), itemMaskUpdated
+                    )
 
                     # Test draw rectangle #
                     toolButton = getQToolButtonFromAction(self.maskWidget.rectAction)
@@ -185,7 +195,8 @@ class TestMaskToolsWidget(PlotWidgetTestCase, ParametricTestCase):
                     self.qapp.processEvents()
                     self._drag()
                     self.assertFalse(
-                        numpy.all(numpy.equal(self.maskWidget.getSelectionMask(), 0)))
+                        numpy.all(numpy.equal(self.maskWidget.getSelectionMask(), 0))
+                    )
                     self.assertTrue(self._isMaskItemSync())
 
                     # unmask same region
@@ -193,7 +204,8 @@ class TestMaskToolsWidget(PlotWidgetTestCase, ParametricTestCase):
                     self.qapp.processEvents()
                     self._drag()
                     self.assertTrue(
-                        numpy.all(numpy.equal(self.maskWidget.getSelectionMask(), 0)))
+                        numpy.all(numpy.equal(self.maskWidget.getSelectionMask(), 0))
+                    )
                     self.assertTrue(self._isMaskItemSync())
 
                     # Test draw polygon #
@@ -206,7 +218,8 @@ class TestMaskToolsWidget(PlotWidgetTestCase, ParametricTestCase):
                     self.qapp.processEvents()
                     self._drawPolygon()
                     self.assertFalse(
-                        numpy.all(numpy.equal(self.maskWidget.getSelectionMask(), 0)))
+                        numpy.all(numpy.equal(self.maskWidget.getSelectionMask(), 0))
+                    )
                     self.assertTrue(self._isMaskItemSync())
 
                     # unmask same region
@@ -214,7 +227,8 @@ class TestMaskToolsWidget(PlotWidgetTestCase, ParametricTestCase):
                     self.qapp.processEvents()
                     self._drawPolygon()
                     self.assertTrue(
-                        numpy.all(numpy.equal(self.maskWidget.getSelectionMask(), 0)))
+                        numpy.all(numpy.equal(self.maskWidget.getSelectionMask(), 0))
+                    )
                     self.assertTrue(self._isMaskItemSync())
 
                     # Test draw pencil #
@@ -230,7 +244,8 @@ class TestMaskToolsWidget(PlotWidgetTestCase, ParametricTestCase):
                     self.qapp.processEvents()
                     self._drawPencil()
                     self.assertFalse(
-                        numpy.all(numpy.equal(self.maskWidget.getSelectionMask(), 0)))
+                        numpy.all(numpy.equal(self.maskWidget.getSelectionMask(), 0))
+                    )
                     self.assertTrue(self._isMaskItemSync())
 
                     # unmask same region
@@ -238,7 +253,8 @@ class TestMaskToolsWidget(PlotWidgetTestCase, ParametricTestCase):
                     self.qapp.processEvents()
                     self._drawPencil()
                     self.assertTrue(
-                        numpy.all(numpy.equal(self.maskWidget.getSelectionMask(), 0)))
+                        numpy.all(numpy.equal(self.maskWidget.getSelectionMask(), 0))
+                    )
                     self.assertTrue(self._isMaskItemSync())
 
                     # Test no draw tool #
@@ -250,8 +266,7 @@ class TestMaskToolsWidget(PlotWidgetTestCase, ParametricTestCase):
 
     def __loadSave(self, file_format):
         """Plot with an image: test MaskToolsWidget operations"""
-        self.plot.addImage(numpy.arange(1024**2).reshape(1024, 1024),
-                           legend='test')
+        self.plot.addImage(numpy.arange(1024**2).reshape(1024, 1024), legend="test")
         self.qapp.processEvents()
 
         # Draw a polygon mask
@@ -264,16 +279,18 @@ class TestMaskToolsWidget(PlotWidgetTestCase, ParametricTestCase):
         self.assertFalse(numpy.all(numpy.equal(ref_mask, 0)))
 
         with temp_dir() as tmp:
-            mask_filename = os.path.join(tmp, 'mask.' + file_format)
+            mask_filename = os.path.join(tmp, "mask." + file_format)
             self.maskWidget.save(mask_filename, file_format)
 
             self.maskWidget.resetSelectionMask()
             self.assertTrue(
-                numpy.all(numpy.equal(self.maskWidget.getSelectionMask(), 0)))
+                numpy.all(numpy.equal(self.maskWidget.getSelectionMask(), 0))
+            )
 
             self.maskWidget.load(mask_filename)
-            self.assertTrue(numpy.all(numpy.equal(
-                self.maskWidget.getSelectionMask(), ref_mask)))
+            self.assertTrue(
+                numpy.all(numpy.equal(self.maskWidget.getSelectionMask(), ref_mask))
+            )
 
     def testLoadSaveNpy(self):
         self.__loadSave("npy")
@@ -282,8 +299,7 @@ class TestMaskToolsWidget(PlotWidgetTestCase, ParametricTestCase):
         self.__loadSave("msk")
 
     def testSigMaskChangedEmitted(self):
-        self.plot.addImage(numpy.arange(512**2).reshape(512, 512),
-                           legend='test')
+        self.plot.addImage(numpy.arange(512**2).reshape(512, 512), legend="test")
         self.plot.resetZoom()
         self.qapp.processEvents()
 
