@@ -1,6 +1,6 @@
 # /*##########################################################################
 #
-# Copyright (c) 2004-2021 European Synchrotron Radiation Facility
+# Copyright (c) 2004-2023 European Synchrotron Radiation Facility
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -38,7 +38,7 @@ def getMouseEventPosition(event):
     :param QMouseEvent event:
     :returns: (x, y) as a tuple of float
     """
-    if _qt.BINDING in ("PyQt5", "PySide2"):
+    if _qt.BINDING == "PyQt5":
         return float(event.x()), float(event.y())
     # Qt6
     position = event.position()
@@ -48,13 +48,8 @@ def getMouseEventPosition(event):
 def supportedImageFormats():
     """Return a set of string of file format extensions supported by the
     Qt runtime."""
-    if _qt.BINDING == 'PySide2':
-        def convert(data):
-            return str(data.data(), 'ascii')
-    else:
-        convert = lambda data: str(data, 'ascii')
     formats = _qt.QImageReader.supportedImageFormats()
-    return set([convert(data) for data in formats])
+    return set([str(data, "ascii") for data in formats])
 
 
 __globalThreadPoolInstance = None
@@ -62,7 +57,7 @@ __globalThreadPoolInstance = None
 
 
 def silxGlobalThreadPool():
-    """"Manage an own QThreadPool to avoid issue on Qt5 Windows with the
+    """Manage an own QThreadPool to avoid issue on Qt5 Windows with the
     default Qt global thread pool.
 
     A thread pool is create in lazy loading. With a maximum of 4 threads.
@@ -71,7 +66,7 @@ def silxGlobalThreadPool():
     :rtype: qt.QThreadPool
     """
     global __globalThreadPoolInstance
-    if __globalThreadPoolInstance is  None:
+    if __globalThreadPoolInstance is None:
         tp = _qt.QThreadPool()
         # Setting maxThreadCount fixes a segfault with PyQt 5.9.1 on Windows
         maxThreadCount = min(4, tp.maxThreadCount())
