@@ -1,5 +1,5 @@
 # /*##########################################################################
-# Copyright (C) 2016-2022 European Synchrotron Radiation Facility
+# Copyright (C) 2016-2023 European Synchrotron Radiation Facility
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -32,14 +32,14 @@ import os.path
 import sys
 import time
 import logging
-import collections
-from typing import Generator
+from typing import Generator, Union, Optional
 import urllib.parse
 
 import numpy
 
 from silx.utils.proxy import Proxy
-import silx.io.url
+from .url import DataUrl
+from . import h5py_utils
 from .._version import calc_hexversion
 
 import h5py
@@ -59,6 +59,7 @@ NEXUS_HDF5_EXT = [".h5", ".nx5", ".nxs", ".hdf", ".hdf5", ".cxi"]
 
 class H5Type(enum.Enum):
     """Identify a set of HDF5 concepts"""
+
     DATASET = 1
     GROUP = 2
     FILE = 3
@@ -70,7 +71,6 @@ class H5Type(enum.Enum):
 _CLASSES_TYPE = None
 """Store mapping between classes and types"""
 
-string_types = (basestring,) if sys.version_info[0] == 2 else (str,)  # noqa
 
 builtin_open = open
 
@@ -86,7 +86,7 @@ def supported_extensions(flat_formats=True):
         extensions (an extension is a string like "\\*.ext").
     :rtype: Dict[str, Set[str]]
     """
-    formats = collections.OrderedDict()
+    formats = {}
     formats["HDF5 files"] = set(["*.h5", "*.hdf", "*.hdf5"])
     formats["NeXus files"] = set(["*.nx", "*.nxs", "*.h5", "*.hdf", "*.hdf5"])
     formats["NeXus layout from spec files"] = set(["*.dat", "*.spec", "*.mca"])
@@ -96,7 +96,9 @@ def supported_extensions(flat_formats=True):
         except ImportError:
             fabioh5 = None
         if fabioh5 is not None:
-            formats["NeXus layout from fabio files"] = set(fabioh5.supported_extensions())
+            formats["NeXus layout from fabio files"] = set(
+                fabioh5.supported_extensions()
+            )
 
     extensions = ["*.npz"]
     if flat_formats:
@@ -108,9 +110,21 @@ def supported_extensions(flat_formats=True):
     return formats
 
 
-def save1D(fname, x, y, xlabel=None, ylabels=None, filetype=None,
-           fmt="%.7g", csvdelim=";", newline="\n", header="",
-           footer="", comments="#", autoheader=False):
+def save1D(
+    fname,
+    x,
+    y,
+    xlabel=None,
+    ylabels=None,
+    filetype=None,
+    fmt="%.7g",
+    csvdelim=";",
+    newline="\n",
+    header="",
+    footer="",
+    comments="#",
+    autoheader=False,
+):
     """Saves any number of curves to various formats: `Specfile`, `CSV`,
     `txt` or `npy`. All curves must have the same number of points and share
     the same ``x`` values.
@@ -169,19 +183,17 @@ def save1D(fname, x, y, xlabel=None, ylabels=None, filetype=None,
     available_formats = ["spec", "csv", "txt", "ndarray"]
 
     if filetype is None:
-        exttypes = {".dat": "spec",
-                    ".csv": "csv",
-                    ".txt": "txt",
-                    ".npy": "ndarray"}
-        outfname = (fname if not hasattr(fname, "name") else
-                    fname.name)
+        exttypes = {".dat": "spec", ".csv": "csv", ".txt": "txt", ".npy": "ndarray"}
+        outfname = fname if not hasattr(fname, "name") else fname.name
         fileext = os.path.splitext(outfname)[1]
         if fileext in exttypes:
             filetype = exttypes[fileext]
         else:
-            raise IOError("File type unspecified and could not be " +
-                          "inferred from file extension (not in " +
-                          "txt, dat, csv, npy)")
+            raise IOError(
+                "File type unspecified and could not be "
+                + "inferred from file extension (not in "
+                + "txt, dat, csv, npy)"
+            )
     else:
         filetype = filetype.lower()
 
@@ -199,8 +211,9 @@ def save1D(fname, x, y, xlabel=None, ylabels=None, filetype=None,
     elif isinstance(ylabels, (list, tuple)):
         # if ylabels is provided as a list, every element must
         # be a string
-        ylabels = [ylabel if isinstance(ylabel, string_types) else "y%d" % i
-                   for ylabel in ylabels]
+        ylabels = [
+            ylabel if isinstance(ylabel, str) else "y%d" % i for ylabel in ylabels
+        ]
 
     if filetype.lower() == "spec":
         # Check if we have regular data:
@@ -211,9 +224,18 @@ def save1D(fname, x, y, xlabel=None, ylabels=None, filetype=None,
         if regular:
             if isinstance(fmt, (list, tuple)) and len(fmt) < (len(ylabels) + 1):
                 fmt = fmt + [fmt[-1] * (1 + len(ylabels) - len(fmt))]
-            specf = savespec(fname, x, y, xlabel, ylabels, fmt=fmt,
-                     scan_number=1, mode="w", write_file_header=True,
-                     close_file=False)
+            specf = savespec(
+                fname,
+                x,
+                y,
+                xlabel,
+                ylabels,
+                fmt=fmt,
+                scan_number=1,
+                mode="w",
+                write_file_header=True,
+                close_file=False,
+            )
         else:
             y_array = numpy.asarray(y)
             # make sure y_array is a 2D array even for a single curve
@@ -223,14 +245,32 @@ def save1D(fname, x, y, xlabel=None, ylabels=None, filetype=None,
                 raise IndexError("y must be a 1D or 2D array")
 
             # First curve
-            specf = savespec(fname, x, y_array[0], xlabel, ylabels[0], fmt=fmt,
-                             scan_number=1, mode="w", write_file_header=True,
-                             close_file=False)
+            specf = savespec(
+                fname,
+                x,
+                y_array[0],
+                xlabel,
+                ylabels[0],
+                fmt=fmt,
+                scan_number=1,
+                mode="w",
+                write_file_header=True,
+                close_file=False,
+            )
             # Other curves
             for i in range(1, y_array.shape[0]):
-                specf = savespec(specf, x, y_array[i], xlabel, ylabels[i],
-                                 fmt=fmt, scan_number=i + 1, mode="w",
-                                 write_file_header=False, close_file=False)
+                specf = savespec(
+                    specf,
+                    x,
+                    y_array[i],
+                    xlabel,
+                    ylabels[i],
+                    fmt=fmt,
+                    scan_number=i + 1,
+                    mode="w",
+                    write_file_header=False,
+                    close_file=False,
+                )
 
         # close file if we created it
         if not hasattr(fname, "write"):
@@ -261,9 +301,16 @@ def save1D(fname, x, y, xlabel=None, ylabels=None, filetype=None,
 
         if filetype.lower() in ["csv", "txt"]:
             X = X.transpose()
-            savetxt(fname, X, fmt=fmt, delimiter=csvdelim,
-                    newline=newline, header=header, footer=footer,
-                    comments=comments)
+            savetxt(
+                fname,
+                X,
+                fmt=fmt,
+                delimiter=csvdelim,
+                newline=newline,
+                header=header,
+                footer=footer,
+                comments=comments,
+            )
 
         elif filetype.lower() == "ndarray":
             if xlabel is not None and ylabels is not None:
@@ -271,14 +318,21 @@ def save1D(fname, x, y, xlabel=None, ylabels=None, filetype=None,
 
                 # .transpose is needed here because recarray labels
                 # apply to columns
-                X = numpy.core.records.fromrecords(X.transpose(),
-                                                   names=labels)
+                X = numpy.core.records.fromrecords(X.transpose(), names=labels)
             numpy.save(fname, X)
 
 
 # Replace with numpy.savetxt when dropping support of numpy < 1.7.0
-def savetxt(fname, X, fmt="%.7g", delimiter=";", newline="\n",
-            header="", footer="", comments="#"):
+def savetxt(
+    fname,
+    X,
+    fmt="%.7g",
+    delimiter=";",
+    newline="\n",
+    header="",
+    footer="",
+    comments="#",
+):
     """``numpy.savetxt`` backport of header and footer arguments from
     numpy=1.7.0.
 
@@ -286,31 +340,35 @@ def savetxt(fname, X, fmt="%.7g", delimiter=";", newline="\n",
     http://docs.scipy.org/doc/numpy-1.10.0/reference/generated/numpy.savetxt.html
     """
     if not hasattr(fname, "name"):
-        ffile = builtin_open(fname, 'wb')
+        ffile = builtin_open(fname, "wb")
     else:
         ffile = fname
 
     if header:
-        if sys.version_info[0] >= 3:
-            header = header.encode("utf-8")
-        ffile.write(header)
+        ffile.write(header.encode("utf-8"))
 
     numpy.savetxt(ffile, X, fmt, delimiter, newline)
 
     if footer:
-        footer = (comments + footer.replace(newline, newline + comments) +
-                  newline)
-        if sys.version_info[0] >= 3:
-            footer = footer.encode("utf-8")
-        ffile.write(footer)
+        footer = comments + footer.replace(newline, newline + comments) + newline
+        ffile.write(footer.encode("utf-8"))
 
     if not hasattr(fname, "name"):
         ffile.close()
 
 
-def savespec(specfile, x, y, xlabel="X", ylabel="Y", fmt="%.7g",
-             scan_number=1, mode="w", write_file_header=True,
-             close_file=False):
+def savespec(
+    specfile,
+    x,
+    y,
+    xlabel="X",
+    ylabel="Y",
+    fmt="%.7g",
+    scan_number=1,
+    mode="w",
+    write_file_header=True,
+    close_file=False,
+):
     """Saves one curve to a SpecFile.
 
     The curve is saved as a scan with two data columns. To save multiple
@@ -324,7 +382,7 @@ def savespec(specfile, x, y, xlabel="X", ylabel="Y", fmt="%.7g",
     :param y: 1D-array (or list), or list of them of ordinates values.
         All dataset must have the same length as x
     :param xlabel: Abscissa label (default ``"X"``)
-    :param ylabel: Ordinate label, may be a list of labels when multiple curves 
+    :param ylabel: Ordinate label, may be a list of labels when multiple curves
         are to be saved together.
     :param fmt: Format string for data. You can specify a short format
         string that defines a single format for both ``x`` and ``y`` values,
@@ -366,13 +424,15 @@ def savespec(specfile, x, y, xlabel="X", ylabel="Y", fmt="%.7g",
     assert len(labels) == ncol
 
     print(xlabel, ylabel, fmt, ncol, x_array, y_array)
-    if isinstance(fmt, string_types) and fmt.count("%") == 1:
+    if isinstance(fmt, str) and fmt.count("%") == 1:
         full_fmt_string = "  ".join([fmt] * ncol)
     elif isinstance(fmt, (list, tuple)) and len(fmt) == ncol:
         full_fmt_string = "  ".join(fmt)
     else:
-        raise ValueError("`fmt` must be a single format string or a list of " +
-                         "format strings with as many format as ncolumns")
+        raise ValueError(
+            "`fmt` must be a single format string or a list of "
+            + "format strings with as many format as ncolumns"
+        )
 
     if not hasattr(specfile, "write"):
         f = builtin_open(specfile, mode)
@@ -381,14 +441,16 @@ def savespec(specfile, x, y, xlabel="X", ylabel="Y", fmt="%.7g",
 
     current_date = "#D %s" % (time.ctime(time.time()))
     if write_file_header:
-        lines = [ "#F %s" % f.name, current_date, ""]
+        lines = ["#F %s" % f.name, current_date, ""]
     else:
         lines = [""]
 
-    lines += [  "#S %d %s" % (scan_number, labels[1]),
-                current_date,
-                "#N %d" % ncol,
-                "#L " + "  ".join(labels)]
+    lines += [
+        "#S %d %s" % (scan_number, labels[1]),
+        current_date,
+        "#N %d" % ncol,
+        "#L " + "  ".join(labels),
+    ]
 
     for i in data.T:
         lines.append(full_fmt_string % tuple(i))
@@ -429,27 +491,27 @@ def h5ls(h5group, lvl=0):
     .. note:: This function requires `h5py <http://www.h5py.org/>`_ to be
         installed.
     """
-    h5repr = ''
+    h5repr = ""
     if is_group(h5group):
         h5f = h5group
-    elif isinstance(h5group, string_types):
+    elif isinstance(h5group, str):
         h5f = open(h5group)  # silx.io.open
     else:
         raise TypeError("h5group must be a hdf5-like group object or a file name.")
 
     for key in h5f.keys():
         # group
-        if hasattr(h5f[key], 'keys'):
-            h5repr += '\t' * lvl + '+' + key
-            h5repr += '\n'
+        if hasattr(h5f[key], "keys"):
+            h5repr += "\t" * lvl + "+" + key
+            h5repr += "\n"
             h5repr += h5ls(h5f[key], lvl + 1)
         # dataset
         else:
-            h5repr += '\t' * lvl
+            h5repr += "\t" * lvl
             h5repr += str(h5f[key])
-            h5repr += '\n'
+            h5repr += "\n"
 
-    if isinstance(h5group, string_types):
+    if isinstance(h5group, str):
         h5f.close()
 
     return h5repr
@@ -482,10 +544,15 @@ def _open_local_file(filename):
         if extension in [".npz", ".npy"]:
             try:
                 from . import rawh5
+
                 return rawh5.NumpyFile(filename)
             except (IOError, ValueError) as e:
-                debugging_info.append((sys.exc_info(),
-                                      "File '%s' can't be read as a numpy file." % filename))
+                debugging_info.append(
+                    (
+                        sys.exc_info(),
+                        "File '%s' can't be read as a numpy file." % filename,
+                    )
+                )
 
         if h5py.is_hdf5(filename):
             try:
@@ -495,29 +562,34 @@ def _open_local_file(filename):
 
         try:
             from . import fabioh5
+
             return fabioh5.File(filename)
         except ImportError:
             debugging_info.append((sys.exc_info(), "fabioh5 can't be loaded."))
         except Exception:
-            debugging_info.append((sys.exc_info(),
-                                   "File '%s' can't be read as fabio file." % filename))
+            debugging_info.append(
+                (sys.exc_info(), "File '%s' can't be read as fabio file." % filename)
+            )
 
         try:
             from . import spech5
+
             return spech5.SpecH5(filename)
         except ImportError:
-            debugging_info.append((sys.exc_info(),
-                                   "spech5 can't be loaded."))
+            debugging_info.append((sys.exc_info(), "spech5 can't be loaded."))
         except IOError:
-            debugging_info.append((sys.exc_info(),
-                                   "File '%s' can't be read as spec file." % filename))
+            debugging_info.append(
+                (sys.exc_info(), "File '%s' can't be read as spec file." % filename)
+            )
 
         try:
             from . import fioh5
+
             return fioh5.FioH5(filename)
         except IOError:
-            debugging_info.append((sys.exc_info(),
-                                   "File '%s' can't be read as fio file." % filename))
+            debugging_info.append(
+                (sys.exc_info(), "File '%s' can't be read as fio file." % filename)
+            )
 
     finally:
         for exc_info, message in debugging_info:
@@ -594,7 +666,7 @@ def open(filename):  # pylint:disable=redefined-builtin
     :raises: IOError if the file can't be loaded or path can't be found
     :rtype: h5py-like node
     """
-    url = silx.io.url.DataUrl(filename)
+    url = DataUrl(filename)
 
     if url.scheme() in [None, "file", "silx"]:
         # That's a local file
@@ -612,13 +684,11 @@ def open(filename):  # pylint:disable=redefined-builtin
         endpoint = "%s://%s" % (uri.scheme, uri.netloc)
         if path.startswith("/"):
             path = path[1:]
-        return h5pyd.File(path, 'r', endpoint=endpoint)
+        return h5pyd.File(path, "r", endpoint=endpoint)
 
-    if url.data_slice():
-        raise IOError("URL '%s' containing slicing is not supported" % filename)
-
-    if url.data_path() in [None, "/", ""]:
-        # The full file is requested
+    if url.data_path() in [None, "/", ""]:  # The full file is requested
+        if url.data_slice():
+            raise IOError(f"URL '{filename}' containing slicing is not supported")
         return h5_file
     else:
         # Only a children is requested
@@ -626,6 +696,17 @@ def open(filename):  # pylint:disable=redefined-builtin
             msg = "File '%s' does not contain path '%s'." % (filename, url.data_path())
             raise IOError(msg)
         node = h5_file[url.data_path()]
+
+        if url.data_slice() is not None:
+            from . import _sliceh5  # Lazy-import to avoid circular dependency
+
+            try:
+                return _sliceh5.DatasetSlice(node, url.data_slice(), attrs=node.attrs)
+            except ValueError:
+                raise IOError(
+                    f"URL {filename} contains slicing, but it is not a dataset"
+                )
+
         proxy = _MainNode(node, h5_file)
         return proxy
 
@@ -642,7 +723,7 @@ def _get_classes_type():
     if _CLASSES_TYPE is not None:
         return _CLASSES_TYPE
 
-    _CLASSES_TYPE = collections.OrderedDict()
+    _CLASSES_TYPE = {}
 
     _CLASSES_TYPE[commonh5.Dataset] = H5Type.DATASET
     _CLASSES_TYPE[commonh5.File] = H5Type.FILE
@@ -793,7 +874,7 @@ def is_link(obj):
     return t in {H5Type.SOFT_LINK, H5Type.EXTERNAL_LINK}
 
 
-def _visitall(item, path=''):
+def _visitall(item, path=""):
     """Helper function for func:`visitall`.
 
     :param item: Item to visit
@@ -807,7 +888,7 @@ def _visitall(item, path=''):
             link = item.get(name, getlink=True)
         else:
             link = child_item
-        child_path = '/'.join((path, name))
+        child_path = "/".join((path, name))
 
         ret = link if link is not None and is_link(link) else child_item
         yield child_path, ret
@@ -822,16 +903,33 @@ def visitall(item):
 
     :param item: The item to visit.
     """
-    yield from _visitall(item, '')
+    yield from _visitall(item, "")
 
 
+def iter_groups(group, _root=None):
+    """Pythonic implementation of h5py.Group visit()"""
+    for name in group.keys():
+        entity = group.get(name)
+        if is_group(entity):
+            yield name
+            for subgroup in iter_groups(entity, _root=name):
+                yield f"{name}/{subgroup}"
+
 
 def match(group, path_pattern: str) -> Generator[str, None, None]:
     """Generator of paths inside given h5py-like `group` matching `path_pattern`"""
     if not is_group(group):
         raise ValueError(f"Not a h5py-like group: {group}")
 
-    path_parts = path_pattern.strip("/").split("/", 1)
+    path_parts = path_pattern.replace("\\", "/").strip("/").split("/", 1)
+    if path_parts[0] == "**":
+        # recursive match
+        for subpath in iter_groups(group):
+            sub = group.get(subpath)
+            for groupname in match(sub, path_parts[1]):
+                yield f"{subpath}/{groupname}"
+        return
+
     for matching_path in fnmatch.filter(group.keys(), path_parts[0]):
         if len(path_parts) == 1:  # No more sub-path, stop recursion
             yield matching_path
@@ -843,7 +941,7 @@ def match(group, path_pattern: str) -> Generator[str, None, None]:
                 yield f"{matching_path}/{matching_subpath}"
 
 
-def get_data(url):
+def get_data(url: Union[str, DataUrl]):
     """Returns a numpy data from an URL.
 
     Examples:
@@ -868,7 +966,7 @@ def get_data(url):
 
     .. seealso:: :class:`silx.io.url.DataUrl`
 
-    :param Union[str,silx.io.url.DataUrl]: A data URL
+    :param url: A data URL
     :rtype: Union[numpy.ndarray, numpy.generic]
     :raises ImportError: If the mandatory library to read the file is not
         available.
@@ -877,8 +975,8 @@ def get_data(url):
         :meth:`fabio.open` or :meth:`silx.io.open`. In this last case more
         informations are displayed in debug mode.
     """
-    if not isinstance(url, silx.io.url.DataUrl):
-        url = silx.io.url.DataUrl(url)
+    if not isinstance(url, DataUrl):
+        url = DataUrl(url)
 
     if not url.is_valid():
         raise ValueError("URL '%s' is not valid" % url.path())
@@ -895,8 +993,10 @@ def get_data(url):
                 raise ValueError("Data path from URL '%s' not found" % url.path())
             data = h5[data_path]
 
-            if not silx.io.is_dataset(data):
-                raise ValueError("Data path from URL '%s' is not a dataset" % url.path())
+            if not is_dataset(data):
+                raise ValueError(
+                    "Data path from URL '%s' is not a dataset" % url.path()
+                )
 
             if data_slice is not None:
                 data = h5py_read_dataset(data, index=data_slice)
@@ -906,24 +1006,36 @@ def get_data(url):
 
     elif url.scheme() == "fabio":
         import fabio
+
         data_slice = url.data_slice()
         if data_slice is None:
             data_slice = (0,)
         if data_slice is None or len(data_slice) != 1:
-            raise ValueError("Fabio slice expect a single frame, but %s found" % data_slice)
+            raise ValueError(
+                "Fabio slice expect a single frame, but %s found" % data_slice
+            )
         index = data_slice[0]
         if not isinstance(index, int):
-            raise ValueError("Fabio slice expect a single integer, but %s found" % data_slice)
+            raise ValueError(
+                "Fabio slice expect a single integer, but %s found" % data_slice
+            )
 
         try:
             fabio_file = fabio.open(url.file_path())
         except Exception:
-            logger.debug("Error while opening %s with fabio", url.file_path(), exc_info=True)
-            raise IOError("Error while opening %s with fabio (use debug for more information)" % url.path())
+            logger.debug(
+                "Error while opening %s with fabio", url.file_path(), exc_info=True
+            )
+            raise IOError(
+                "Error while opening %s with fabio (use debug for more information)"
+                % url.path()
+            )
 
         if fabio_file.nframes == 1:
             if index != 0:
-                raise ValueError("Only a single frame available. Slice %s out of range" % index)
+                raise ValueError(
+                    "Only a single frame available. Slice %s out of range" % index
+                )
             data = fabio_file.data
         else:
             data = fabio_file.getframe(index).data
@@ -931,14 +1043,31 @@ def get_data(url):
         # There is no explicit close
         fabio_file = None
 
+    elif url.scheme() is None:
+        for scheme in ("silx", "fabio"):
+            specificUrl = DataUrl(
+                file_path=url.file_path(),
+                data_slice=url.data_slice(),
+                data_path=url.data_path(),
+                scheme=scheme,
+            )
+            try:
+                data = get_data(specificUrl)
+            except Exception:
+                logger.debug(
+                    "Error while trying to loading %s as %s", url, scheme, exc_info=True
+                )
+            else:
+                break
+        else:
+            raise ValueError(f"Data from '{url}' is not readable as silx nor fabio")
     else:
         raise ValueError("Scheme '%s' not supported" % url.scheme())
 
     return data
 
 
-def rawfile_to_h5_external_dataset(bin_file, output_url, shape, dtype,
-                                   overwrite=False):
+def rawfile_to_h5_external_dataset(bin_file, output_url, shape, dtype, overwrite=False):
     """
     Create a HDF5 dataset at `output_url` pointing to the given vol_file.
 
@@ -950,29 +1079,34 @@ def rawfile_to_h5_external_dataset(bin_file, output_url, shape, dtype,
     :param numpy.dtype dtype: Data type of the volume elements (default: float32)
     :param bool overwrite: True to allow overwriting (default: False).
     """
-    assert isinstance(output_url, silx.io.url.DataUrl)
+    assert isinstance(output_url, DataUrl)
     assert isinstance(shape, (tuple, list))
-    v_majeur, v_mineur, v_micro = [int(i) for i in h5py.version.version.split('.')[:3]]
-    if calc_hexversion(v_majeur, v_mineur, v_micro)< calc_hexversion(2,9,0):
-        raise Exception('h5py >= 2.9 should be installed to access the '
-                        'external feature.')
+    v_majeur, v_mineur, v_micro = [int(i) for i in h5py.version.version.split(".")[:3]]
+    if calc_hexversion(v_majeur, v_mineur, v_micro) < calc_hexversion(2, 9, 0):
+        raise Exception(
+            "h5py >= 2.9 should be installed to access the " "external feature."
+        )
 
     with h5py.File(output_url.file_path(), mode="a") as _h5_file:
         if output_url.data_path() in _h5_file:
             if overwrite is False:
-                raise ValueError('data_path already exists')
+                raise ValueError("data_path already exists")
             else:
-                logger.warning('will overwrite path %s' % output_url.data_path())
+                logger.warning("will overwrite path %s" % output_url.data_path())
                 del _h5_file[output_url.data_path()]
         external = [(bin_file, 0, h5py.h5f.UNLIMITED)]
-        _h5_file.create_dataset(output_url.data_path(),
-                                shape,
-                                dtype=dtype,
-                                external=external)
+        _h5_file.create_dataset(
+            output_url.data_path(), shape, dtype=dtype, external=external
+        )
 
 
-def vol_to_h5_external_dataset(vol_file, output_url, info_file=None,
-                               vol_dtype=numpy.float32, overwrite=False):
+def vol_to_h5_external_dataset(
+    vol_file,
+    output_url: DataUrl,
+    info_file: Optional[str] = None,
+    vol_dtype=numpy.float32,
+    overwrite=False,
+):
     """
     Create a HDF5 dataset at `output_url` pointing to the given vol_file.
 
@@ -980,8 +1114,8 @@ def vol_to_h5_external_dataset(vol_file, output_url, info_file=None,
      vol-file then you should specify her location.
 
     :param str vol_file: Path to the .vol file
-    :param DataUrl output_url: HDF5 URL where to save the external dataset
-    :param Union[str,None] info_file:
+    :param output_url: HDF5 URL where to save the external dataset
+    :param info_file:
         .vol.info file name written by pyhst and containing the shape information
     :param numpy.dtype vol_dtype: Data type of the volume elements (default: float32)
     :param bool overwrite: True to allow overwriting (default: False).
@@ -989,10 +1123,12 @@ def vol_to_h5_external_dataset(vol_file, output_url, info_file=None,
     """
     _info_file = info_file
     if _info_file is None:
-        _info_file = vol_file + '.info'
+        _info_file = vol_file + ".info"
         if not os.path.exists(_info_file):
-            logger.error('info_file not given and %s does not exists, please'
-                         'specify .vol.info file' % _info_file)
+            logger.error(
+                "info_file not given and %s does not exists, please"
+                "specify .vol.info file" % _info_file
+            )
             return
 
     def info_file_to_dict():
@@ -1000,29 +1136,49 @@ def vol_to_h5_external_dataset(vol_file, output_url, info_file=None,
         with builtin_open(info_file, "r") as _file:
             lines = _file.readlines()
             for line in lines:
-                if not '=' in line:
+                if not "=" in line:
                     continue
-                l = line.rstrip().replace(' ', '')
-                l = l.split('#')[0]
-                key, value = l.split('=')
+                l = line.rstrip().replace(" ", "")
+                l = l.split("#")[0]
+                key, value = l.split("=")
                 ddict[key.lower()] = value
         return ddict
 
     ddict = info_file_to_dict()
-    if 'num_x' not in ddict or 'num_y' not in ddict or 'num_z' not in ddict:
-        raise ValueError(
-            'Unable to retrieve volume shape from %s' % info_file)
+    if "num_x" not in ddict or "num_y" not in ddict or "num_z" not in ddict:
+        raise ValueError("Unable to retrieve volume shape from %s" % info_file)
 
-    dimX = int(ddict['num_x'])
-    dimY = int(ddict['num_y'])
-    dimZ = int(ddict['num_z'])
+    dimX = int(ddict["num_x"])
+    dimY = int(ddict["num_y"])
+    dimZ = int(ddict["num_z"])
     shape = (dimZ, dimY, dimX)
 
-    return rawfile_to_h5_external_dataset(bin_file=vol_file,
-                                          output_url=output_url,
-                                          shape=shape,
-                                          dtype=vol_dtype,
-                                          overwrite=overwrite)
+    return rawfile_to_h5_external_dataset(
+        bin_file=vol_file,
+        output_url=output_url,
+        shape=shape,
+        dtype=vol_dtype,
+        overwrite=overwrite,
+    )
+
+
+def hdf5_to_python_type(value, decode_ascii, encoding):
+    """Convert HDF5 type to proper python type.
+
+    :param value:
+    :param bool decode_ascii:
+    :param encoding str:
+    """
+    if encoding == "ascii":
+        is_bytes = h5py_value_isinstance(value, bytes)
+        if is_bytes and decode_ascii:
+            return h5py_decode_value(value, encoding="utf-8")
+        if not is_bytes and not decode_ascii:
+            return h5py_encode_value(value, encoding="utf-8")
+    elif encoding == "utf-8":
+        if h5py_value_isinstance(value, bytes):
+            return h5py_decode_value(value, encoding="utf-8")
+    return value
 
 
 def h5py_decode_value(value, encoding="utf-8", errors="surrogateescape"):
@@ -1034,8 +1190,8 @@ def h5py_decode_value(value, encoding="utf-8", errors="surrogateescape"):
     """
     try:
         if numpy.isscalar(value):
-            return value.decode(encoding, errors=errors)
-        str_item = [b.decode(encoding, errors=errors) for b in value.flat]
+            return _decode_string(value, encoding, errors)
+        str_item = [_decode_string(b, encoding, errors) for b in value.flat]
         return numpy.array(str_item, dtype=object).reshape(value.shape)
     except UnicodeDecodeError:
         return value
@@ -1050,13 +1206,55 @@ def h5py_encode_value(value, encoding="utf-8", errors="surrogateescape"):
     """
     try:
         if numpy.isscalar(value):
-            return value.encode(encoding, errors=errors)
-        bytes_item = [s.encode(encoding, errors=errors) for s in value.flat]
+            return _encode_string(value, encoding, errors)
+        bytes_item = [_encode_string(s, encoding, errors=errors) for s in value.flat]
         return numpy.array(bytes_item, dtype=object).reshape(value.shape)
     except UnicodeEncodeError:
         return value
 
 
+def h5py_value_isinstance(value, vtype):
+    """Keep string when value cannot be encoding
+
+    :param value: string or array of strings
+    :param vtype:
+    :return bool:
+    """
+    if numpy.isscalar(value):
+        try:
+            value = value.item()
+        except AttributeError:
+            pass
+    else:
+        try:
+            value = value[0]
+        except IndexError:
+            pass
+    return isinstance(value, vtype)
+
+
+def _decode_string(string, encoding, errors):
+    """
+    :param value: string
+    :param encoding str:
+    :param errors str:
+    """
+    if isinstance(string, str):
+        return string
+    return string.decode(encoding, errors=errors)
+
+
+def _encode_string(string, encoding, errors):
+    """
+    :param value: string
+    :param encoding str:
+    :param errors str:
+    """
+    if isinstance(string, bytes):
+        return string
+    return string.encode(encoding, errors=errors)
+
+
 class H5pyDatasetReadWrapper:
     """Wrapper to handle H5T_STRING decoding on-the-fly when reading
     a dataset. Uniform behaviour for h5py 2.x and h5py 3.x
@@ -1066,13 +1264,12 @@ class H5pyDatasetReadWrapper:
     Therefore an H5T_STRING with ASCII encoding is not decoded by default.
     """
 
-    H5PY_AUTODECODE_NONASCII = int(h5py.version.version.split(".")[0]) < 3
-
     def __init__(self, dset, decode_ascii=False):
         """
         :param h5py.Dataset dset:
         :param bool decode_ascii:
         """
+        # Get the string encoding (if a string)
         try:
             string_info = h5py.h5t.check_string_dtype(dset.dtype)
         except AttributeError:
@@ -1091,23 +1288,14 @@ class H5pyDatasetReadWrapper:
             except AttributeError:
                 # Not an H5T_STRING
                 encoding = None
-        if encoding == "ascii" and not decode_ascii:
-            encoding = None
-        if encoding != "ascii" and self.H5PY_AUTODECODE_NONASCII:
-            # Decoding is already done by the h5py library
-            encoding = None
-        if encoding == "ascii":
-            # ASCII can be decoded as UTF-8
-            encoding = "utf-8"
+
         self._encoding = encoding
+        self._decode_ascii = decode_ascii
         self._dset = dset
 
     def __getitem__(self, args):
         value = self._dset[args]
-        if self._encoding:
-            return h5py_decode_value(value, encoding=self._encoding)
-        else:
-            return value
+        return hdf5_to_python_type(value, self._decode_ascii, self._encoding)
 
 
 class H5pyAttributesReadWrapper:
@@ -1119,8 +1307,6 @@ class H5pyAttributesReadWrapper:
     Therefore an H5T_STRING with ASCII encoding is not decoded by default.
     """
 
-    H5PY_AUTODECODE = int(h5py.version.version.split(".")[0]) >= 3
-
     def __init__(self, attrs, decode_ascii=False):
         """
         :param h5py.Dataset dset:
@@ -1153,17 +1339,7 @@ class H5pyAttributesReadWrapper:
                 # Not an H5T_STRING
                 return value
 
-        if self.H5PY_AUTODECODE:
-            if encoding == "ascii" and not self._decode_ascii:
-                # Undo decoding by the h5py library
-                return h5py_encode_value(value, encoding="utf-8")
-        else:
-            if encoding == "ascii" and self._decode_ascii:
-                # Decode ASCII as UTF-8 for consistency
-                return h5py_decode_value(value, encoding="utf-8")
-
-        # Decoding is already done by the h5py library
-        return value
+        return hdf5_to_python_type(value, self._decode_ascii, encoding)
 
     def items(self):
         for k in self._attrs.keys():
