@@ -1,5 +1,5 @@
 # /*##########################################################################
-# Copyright (C) 2016-2020 European Synchrotron Radiation Facility
+# Copyright (C) 2016-2022 European Synchrotron Radiation Facility
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -27,8 +27,6 @@ __license__ = "MIT"
 __date__ = "17/01/2018"
 
 
-import unittest
-
 import numpy
 
 from silx.utils.testutils import ParametricTestCase
@@ -39,11 +37,11 @@ from silx.math.combo import min_max
 class TestMinMax(ParametricTestCase):
     """Tests of min max combo"""
 
-    FLOATING_DTYPES = 'float32', 'float64'
+    FLOATING_DTYPES = "float32", "float64"
     if hasattr(numpy, "float128"):
-        FLOATING_DTYPES += ('float128',)
-    SIGNED_INT_DTYPES = 'int8', 'int16', 'int32', 'int64'
-    UNSIGNED_INT_DTYPES = 'uint8', 'uint16', 'uint32', 'uint64'
+        FLOATING_DTYPES += ("float128",)
+    SIGNED_INT_DTYPES = "int8", "int16", "int32", "int64"
+    UNSIGNED_INT_DTYPES = "uint8", "uint16", "uint32", "uint64"
     DTYPES = FLOATING_DTYPES + SIGNED_INT_DTYPES + UNSIGNED_INT_DTYPES
 
     def _numpy_min_max(self, data, min_positive=False, finite=False):
@@ -55,7 +53,7 @@ class TestMinMax(ParametricTestCase):
         """
         data = numpy.array(data, copy=False)
         if data.size == 0:
-            raise ValueError('Zero-sized array')
+            raise ValueError("Zero-sized array")
 
         minimum = None
         argmin = None
@@ -84,7 +82,7 @@ class TestMinMax(ParametricTestCase):
                 argmax = numpy.where(data == maximum)[0][0]
 
             if min_positive:
-                with numpy.errstate(invalid='ignore'):
+                with numpy.errstate(invalid="ignore"):
                     # Ignore invalid value encountered in greater
                     pos_data = filtered_data[filtered_data > 0]
                 if pos_data.size > 0:
@@ -100,8 +98,9 @@ class TestMinMax(ParametricTestCase):
         :param bool min_positive: True to test with positive min
         :param bool finite: True to only test finite values
         """
-        minimum, min_pos, maximum, argmin, argmin_pos, argmax = \
-            self._numpy_min_max(data, min_positive, finite)
+        minimum, min_pos, maximum, argmin, argmin_pos, argmax = self._numpy_min_max(
+            data, min_positive, finite
+        )
 
         result = min_max(data, min_positive, finite)
 
@@ -114,30 +113,28 @@ class TestMinMax(ParametricTestCase):
 
     def assertSimilar(self, a, b):
         """Assert that a and b are both None or NaN or that a == b."""
-        self.assertTrue((a is None and b is None) or
-                        (numpy.isnan(a) and numpy.isnan(b)) or
-                        a == b)
+        self.assertTrue(
+            (a is None and b is None) or (numpy.isnan(a) and numpy.isnan(b)) or a == b
+        )
 
     def test_different_datasets(self):
         """Test min_max with different numpy.arange datasets."""
         size = 1000
 
         for dtype in self.DTYPES:
-
-            tests = {
-                '0 to N': (0, 1),
-                'N-1 to 0': (size - 1, -1)}
+            tests = {"0 to N": (0, 1), "N-1 to 0": (size - 1, -1)}
             if dtype not in self.UNSIGNED_INT_DTYPES:
-                tests['N/2 to -N/2'] = size // 2, -1
-                tests['0 to -N'] = 0, -1
+                tests["N/2 to -N/2"] = size // 2, -1
+                tests["0 to -N"] = 0, -1
 
             for name, (start, step) in tests.items():
                 for min_positive in (True, False):
-                    with self.subTest(dtype=dtype,
-                                      min_positive=min_positive,
-                                      data=name):
-                        data = numpy.arange(
-                            start, start + step * size, step, dtype=dtype)
+                    with self.subTest(
+                        dtype=dtype, min_positive=min_positive, data=name
+                    ):
+                        data = numpy.arange(start, start + step * size, step).astype(
+                            dtype
+                        )
 
                         self._test_min_max(data, min_positive)
 
@@ -147,18 +144,18 @@ class TestMinMax(ParametricTestCase):
             with self.subTest(dtype=dtype):
                 with self.assertRaises(TypeError):
                     min_max(None)
-                
+
                 data = numpy.array((), dtype=dtype)
                 with self.assertRaises(ValueError):
                     min_max(data)
 
     NAN_TEST_DATA = [
-        (float('nan'), float('nan')),  # All NaNs
-        (float('nan'), 1.0),  # NaN first and positive
-        (float('nan'), -1.0),  # NaN first and negative
-        (1.0, 2.0, float('nan')),  # NaN last and positive
-        (-1.0, -2.0, float('nan')),  # NaN last and negative
-        (1.0, float('nan'), -1.0),  # Some NaN
+        (float("nan"), float("nan")),  # All NaNs
+        (float("nan"), 1.0),  # NaN first and positive
+        (float("nan"), -1.0),  # NaN first and negative
+        (1.0, 2.0, float("nan")),  # NaN last and positive
+        (-1.0, -2.0, float("nan")),  # NaN last and negative
+        (1.0, float("nan"), -1.0),  # Some NaN
     ]
 
     def test_nandata(self):
@@ -170,12 +167,12 @@ class TestMinMax(ParametricTestCase):
                     self._test_min_max(data, min_positive=True)
 
     INF_TEST_DATA = [
-        [float('inf')] * 3,  # All +inf
-        [float('-inf')] * 3,  # All -inf
-        (float('inf'), float('-inf')),  # + and - inf
-        (float('inf'), float('-inf'), float('nan')),  # +/-inf, nan last
-        (float('nan'), float('-inf'), float('inf')),  # +/-inf, nan first
-        (float('inf'), float('nan'), float('-inf')),  # +/-inf, nan center
+        [float("inf")] * 3,  # All +inf
+        [float("-inf")] * 3,  # All -inf
+        (float("inf"), float("-inf")),  # + and - inf
+        (float("inf"), float("-inf"), float("nan")),  # +/-inf, nan last
+        (float("nan"), float("-inf"), float("inf")),  # +/-inf, nan first
+        (float("inf"), float("nan"), float("-inf")),  # +/-inf, nan center
     ]
 
     def test_infdata(self):
@@ -189,10 +186,10 @@ class TestMinMax(ParametricTestCase):
     def test_finite(self):
         """Test min_max with finite=True"""
         tests = [
-            (-1., 2., 0.),  # Basic test
-            (float('nan'), float('inf'), float('-inf')),  # NaN + Inf
-            (float('nan'), float('inf'), -2, float('-inf')),  # NaN + Inf + 1 value
-            (float('inf'), -3, -2), # values + inf
+            (-1.0, 2.0, 0.0),  # Basic test
+            (float("nan"), float("inf"), float("-inf")),  # NaN + Inf
+            (float("nan"), float("inf"), -2, float("-inf")),  # NaN + Inf + 1 value
+            (float("inf"), -3, -2),  # values + inf
         ]
         tests += self.INF_TEST_DATA
         tests += self.NAN_TEST_DATA
